@@ -55,6 +55,7 @@ class RuboCopRunner
   # @return [Integer] RuboCop::CLI status code
   def run(full_filepath, options = {})
     unless requires_rubocop?(full_filepath)
+      puts "#{full_filepath} - [*] Rubocop not required for older modules skipping. If making a large update - run rubocop #{"rubocop -a #{full_filepath}".yellow} and verify all issues are resolved"
       return RuboCop::CLI::STATUS_SUCCESS
     end
 
@@ -320,7 +321,7 @@ class MsftidyRunner
 
   # See if 'require "rubygems"' or equivalent is used, and
   # warn if so. Since Ruby 1.9 this has not been necessary and
-  # the framework only suports 1.9+
+  # the framework only supports 1.9+
   def check_rubygems
     @lines.each do |line|
       if line_has_require?(line, 'rubygems')
@@ -922,6 +923,8 @@ class Msftidy
 
           rubocop_result = rubocop_runner.run(full_filepath, options)
           @exit_status = MsftidyRunner::ERROR if rubocop_result != RuboCop::CLI::STATUS_SUCCESS
+
+          return @exit_status if options[:fail_fast] && @exit_status != 0
         end
       rescue Errno::ENOENT
         $stderr.puts "#{File.basename(__FILE__)}: #{dir}: No such file or directory"
@@ -954,6 +957,10 @@ if __FILE__ == $PROGRAM_NAME
     opts.on('-A', '--auto-correct-all', 'Auto-correct offenses (safe and unsafe).') do |auto_correct_all|
       options[:auto_correct_all] = auto_correct_all
     end
+
+    opts.on('--fail-fast', 'Exit after the first detected failure instead of processing the rest of the files.') do |fail_fast|
+      options[:fail_fast] = fail_fast
+    end
   end
   options_parser.parse!
 
