@@ -6,8 +6,8 @@ build () {
   CFLAGS=$3
 
   echo "[*] Building for ${TARGET_SUFFIX}..."
-  for type in {shellcode,system,findsock}
-   do ${CC} ${CFLAGS} -Wall -Werror -fPIC -fno-stack-protector samba-root-${type}.c -shared -o samba-root-${type}-${TARGET_SUFFIX}.so
+  for type in {shellcode,system,reverse,bind}
+   do ${CC} ${CFLAGS} -Wall -fPIC -fno-stack-protector -Os goahead-cgi-${type}.c -s -shared -o goahead-cgi-${type}-${TARGET_SUFFIX}.so
   done
 }
 
