@@ -138,6 +138,7 @@ class Meterpreter < Rex::Post::Meterpreter::Client
   end
 
   def load_embedded_extensions
+    # Rex::Post::Meterpreter::ExtensionMapper.get_extension_klasses
 
     # First of all, let's see if we have stdapi.
     commands = self.core.get_loaded_extension_commands('stdapi')
@@ -206,7 +207,7 @@ class Meterpreter < Rex::Post::Meterpreter::Client
 
     load_embedded_extensions
 
-    extensions = datastore['AutoLoadExtensions']&.delete(' ').split(',') || []
+    extensions = datastore['AutoLoadExtensions']&.delete(' ')&.split(',') || []
 
     # BEGIN: This should be removed on MSF 7
     # Unhook the process prior to loading stdapi to reduce logging/inspection by any AV/PSP (by default unhook is first, see meterpreter_options/windows.rb)
