@@ -179,7 +179,7 @@ module Msf
             pfx = options[:pfx]
             request_pac = options.fetch(:request_pac, true)
             realm = options[:realm]
-            server_name = options.fetch(:server_name, "krbtgt/#{realm}")
+            server_name = options[:server_name] || "krbtgt/#{realm}"
             client_name = options[:client_name]
             client_name = client_name.dup.force_encoding('utf-8') if client_name
             ticket_options = options.fetch(:options) { 0x50800000 } # Forwardable, Proxiable, Renewable
@@ -245,7 +245,7 @@ module Msf
           # @raise [Rex::Proto::Kerberos::Model::Error::KerberosError] if the provided credentials are invalid
           def send_request_tgt(options = {})
             realm = options[:realm]
-            server_name = options[:server_name]
+            server_name = options[:server_name] || "krbtgt/#{realm}"
             client_name = options[:client_name]
             client_name = client_name.dup.force_encoding('utf-8') if client_name
             password = options[:password]
