@@ -89,6 +89,7 @@ class Msf::Exploit::Remote::Kerberos::ServiceAuthenticator::Base
   def_delegators :@framework_module,
                 :print_status,
                 :print_good,
+                :print_error,
                 :vprint_error,
                 :vprint_status,
                 :workspace
@@ -156,8 +157,9 @@ class Msf::Exploit::Remote::Kerberos::ServiceAuthenticator::Base
     credential = nil
     if cache_file.present?
       # the cache file is only used for loading credentials, it is *not* written to
-      credential = load_credential_from_file(cache_file, sname: nil, sname_hostname: @hostname)
-      serviceclass = build_spn.name_string.first
+      load_sname_hostname_credential_result = load_credential_from_file(cache_file, sname: nil, sname_hostname: @hostname)
+      credential = load_sname_hostname_credential_result&.fetch(:credential, nil)
+      serviceclass = build_spn&.name_string&.first
       if credential && credential.server.components[0] != serviceclass
         old_sname = credential.server.components.snapshot.join('/')
         credential.server.components[0] = serviceclass
@@ -167,9 +169,20 @@ class Msf::Exploit::Remote::Kerberos::ServiceAuthenticator::Base
         ticket.sname.name_string[0] = serviceclass
         credential.ticket = ticket.encode
       elsif credential.nil? && hostname.present?
-        credential = load_credential_from_file(cache_file, sname: "krbtgt/#{hostname.split('.', 2).last}")
+        load_sname_krbtgt_hostname_credential_result = load_credential_from_file(cache_file, sname: "krbtgt/#{hostname.split('.', 2).last}")
+        credential = load_sname_krbtgt_hostname_credential_result&.fetch(:credential, nil)
       end
       if credential.nil?
+        print_error("Failed to load a usable credential from ticket file: #{cache_file}")
+        if load_sname_hostname_credential_result
+          print_error("Attempt failed to find a valid credential in #{cache_file} for #{load_sname_hostname_credential_result[:filter].map { |k, v| "#{k}=#{v.inspect}" }.join(', ')}:")
+          print_error(load_sname_hostname_credential_result[:filter_reasons].join("\n").indent(2))
+        end
+
+        if load_sname_krbtgt_hostname_credential_result
+          print_error("Attempt failed to find a valid credential in #{cache_file} for #{load_sname_krbtgt_hostname_credential_result[:filter].map { |k, v| "#{k}=#{v.inspect}" }.join(', ')}")
+          print_error(load_sname_krbtgt_hostname_credential_result[:filter_reasons].join("\n").indent(2))
+        end
         raise ::Rex::Proto::Kerberos::Model::Error::KerberosError.new("Failed to load a usable credential from ticket file: #{cache_file}")
       end
       print_status("Loaded a credential from ticket file: #{cache_file}")
@@ -211,6 +224,7 @@ class Msf::Exploit::Remote::Kerberos::ServiceAuthenticator::Base
   # @param [Hash] options
   # @option options [String] :credential An explicit credential object to use for authentication.
   # @option options [Rex::Proto::Kerberos::Model::PrincipalName] :sname The target service principal name.
+  # @option options [String] :sname The target service principal name.
   # @option options [String] :mechanism The authentication mechanism. One of the Rex::Proto::Gss::Mechanism constants.
   # @return [Hash] The security_blob SPNEGO GSS and TGS session key
   def authenticate(options = {})
@@ -360,7 +374,7 @@ class Msf::Exploit::Remote::Kerberos::ServiceAuthenticator::Base
   # @return [Rex::Proto::Kerberos::CredentialCache::Krb5CcacheCredential] The ccache credential
   def request_tgt_only(options = {})
     if options[:cache_file]
-      credential = load_credential_from_file(options[:cache_file])
+      credential = load_credential_from_file(options[:cache_file])&.fetch(:credential, nil)
     else
       credential = get_cached_credential(
         options.merge(
@@ -646,6 +660,119 @@ class Msf::Exploit::Remote::Kerberos::ServiceAuthenticator::Base
     { credential: credential, session_key: session_key, krb_enc_key: tgt_result.krb_enc_key }
   end
 
+  # @param [Rex::Proto::Kerberos::Model::EncryptionKey] session_key
+  # @param [Rex::Proto::Kerberos::Model::Ticket] tgt_ticket
+  # @param [String] realm
+  # @param [String] client_name
+  # @param [Integer] etypes
+  # @param [Time] expiry_time
+  # @param [Time] now
+  # @param [Rex::Proto::Kerberos::Model::PrincipalName] sname
+  # @param [Hash] options
+  # @option options [Array<Rex::Proto::Kerberos::Model::KdcOptionFlags>] :additional_flags
+  #   Any additional flags to add to the TGS request option flags. The
+  #   FORWARDABLE, RENEWABLE and CANONICALIZE flags are set by default.
+  # @option options [Array<Rex::Proto::Kerberos::Model::Ticket>] :additional_tickets
+  #   Any additional tickets to add to the request
+  # @option options [Array<Rex::Proto::Kerberos::Model::PreAuthDataEntry>] :pa_data
+  #   Any additional pre-auth data entries to add to the request
+  # @option options [Msf::Exploit::Remote::Kerberos::Ticket::Storage::Base] :ticket_storage Override the @ticket_storage attribute
+  # @option options [String] :credential_cache_username The name of user
+  #   corresponding to the requested TGS ticket. This name will be used in
+  #   the info field when the tickets is stored in the database. This can be used
+  #   to override the original username in case of impersonation.
+  # @raise [Rex::Proto::Kerberos::Model::Error::KerberosError]
+  # @return [Array] The TGS ticket and the decrypted TGS credentials as a MIT Cache Credential
+  def request_service_ticket(session_key, tgt_ticket, realm, client_name, etypes, expiry_time, now, sname, options = {})
+    etypes = etypes.is_a?(::Enumerable) ? etypes : [etypes]
+
+    flags = Set.new([
+      Rex::Proto::Kerberos::Model::KdcOptionFlags::FORWARDABLE,
+      Rex::Proto::Kerberos::Model::KdcOptionFlags::RENEWABLE,
+      Rex::Proto::Kerberos::Model::KdcOptionFlags::CANONICALIZE,
+    ])
+    if options[:additional_flags].present?
+      additional_flags = options[:additional_flags]
+      additional_flags = [additional_flags] unless additional_flags.is_a?(::Enumerable)
+      flags.merge(additional_flags)
+    end
+    ticket_options = Rex::Proto::Kerberos::Model::KdcOptionFlags.from_flags(flags)
+
+    tgs_body_options = {
+      cname: nil,
+      sname: sname,
+      realm: realm,
+      etype: etypes,
+      options: ticket_options,
+
+      # Specify nil to ensure the KDC uses the current time for the desired starttime of the requested ticket
+      from: nil,
+      till: expiry_time,
+      rtime: nil,
+
+      # certificate time
+      ctime: now
+    }
+    if options[:additional_tickets].present?
+      additional_tickets = options[:additional_tickets]
+      additional_tickets = [additional_tickets] unless additional_tickets.is_a?(::Enumerable)
+      tgs_body_options[:additional_tickets] = additional_tickets
+    end
+
+    tgs_options = {
+      session_key: session_key,
+      subkey: nil,
+      checksum: nil,
+      ticket: tgt_ticket,
+      realm: realm,
+      client_name: client_name,
+      options: ticket_options,
+
+      body: build_tgs_request_body(**tgs_body_options)
+    }
+    if options[:pa_data].present?
+      pa_data = [options[:pa_data]] unless options[:pa_data].is_a?(::Enumerable)
+      tgs_options[:pa_data] = pa_data
+    end
+
+    tgs_res = send_request_tgs(
+        req: build_tgs_request(tgs_options)
+    )
+
+    # Verify error codes
+    if tgs_res.msg_type == Rex::Proto::Kerberos::Model::KRB_ERROR
+      raise ::Rex::Proto::Kerberos::Model::Error::KerberosError.new(res: tgs_res)
+    end
+
+    print_good("#{peer} - Received a valid TGS-Response")
+
+    ccache = extract_kerb_creds(
+      tgs_res,
+      session_key.value,
+      msg_type: Rex::Proto::Kerberos::Crypto::KeyUsage::TGS_REP_ENCPART_SESSION_KEY
+    )
+    if options[:credential_cache_username].present?
+      client = options[:credential_cache_username]
+    else
+      client = self.username
+    end
+    options.fetch(:ticket_storage, @ticket_storage).store_ccache(
+      ccache,
+      host: rhost,
+      client: client,
+      server: sname
+    )
+
+    tgs_ticket = tgs_res.ticket
+    tgs_auth = decrypt_kdc_tgs_rep_enc_part(
+      tgs_res,
+      session_key.value,
+      msg_type: Rex::Proto::Kerberos::Crypto::KeyUsage::TGS_REP_ENCPART_SESSION_KEY
+    )
+
+    [tgs_ticket, tgs_auth]
+  end
+
   private
 
   # Authenticate with a ticket-granting-service (TGS). This method will not contact the KDC and can not request a
@@ -924,119 +1051,6 @@ class Msf::Exploit::Remote::Kerberos::ServiceAuthenticator::Base
     [delegated_tgs_ticket, delegated_tgs_auth]
   end
 
-  # @param [Rex::Proto::Kerberos::Model::EncryptionKey] session_key
-  # @param [Rex::Proto::Kerberos::Model::Ticket] tgt_ticket
-  # @param [String] realm
-  # @param [String] client_name
-  # @param [Integer] etypes
-  # @param [Time] expiry_time
-  # @param [Time] now
-  # @param [Rex::Proto::Kerberos::Model::PrincipalName] sname
-  # @param [Hash] options
-  # @option options [Array<Rex::Proto::Kerberos::Model::KdcOptionFlags>] :additional_flags
-  #   Any additional flags to add to the TGS request option flags. The
-  #   FORWARDABLE, RENEWABLE and CANONICALIZE flags are set by default.
-  # @option options [Array<Rex::Proto::Kerberos::Model::Ticket>] :additional_tickets
-  #   Any additional tickets to add to the request
-  # @option options [Array<Rex::Proto::Kerberos::Model::PreAuthDataEntry>] :pa_data
-  #   Any additional pre-auth data entries to add to the request
-  # @option options [Msf::Exploit::Remote::Kerberos::Ticket::Storage::Base] :ticket_storage Override the @ticket_storage attribute
-  # @option options [String] :credential_cache_username The name of user
-  #   corresponding to the requested TGS ticket. This name will be used in
-  #   the info field when the tickets is stored in the database. This can be used
-  #   to override the original username in case of impersonation.
-  # @raise [Rex::Proto::Kerberos::Model::Error::KerberosError]
-  # @return [Array] The TGS ticket and the decrypted TGS credentials as a MIT Cache Credential
-  def request_service_ticket(session_key, tgt_ticket, realm, client_name, etypes, expiry_time, now, sname, options = {})
-    etypes = etypes.is_a?(::Enumerable) ? etypes : [etypes]
-
-    flags = Set.new([
-      Rex::Proto::Kerberos::Model::KdcOptionFlags::FORWARDABLE,
-      Rex::Proto::Kerberos::Model::KdcOptionFlags::RENEWABLE,
-      Rex::Proto::Kerberos::Model::KdcOptionFlags::CANONICALIZE,
-    ])
-    if options[:additional_flags].present?
-      additional_flags = options[:additional_flags]
-      additional_flags = [additional_flags] unless additional_flags.is_a?(::Enumerable)
-      flags.merge(additional_flags)
-    end
-    ticket_options = Rex::Proto::Kerberos::Model::KdcOptionFlags.from_flags(flags)
-
-    tgs_body_options = {
-      cname: nil,
-      sname: sname,
-      realm: realm,
-      etype: etypes,
-      options: ticket_options,
-
-      # Specify nil to ensure the KDC uses the current time for the desired starttime of the requested ticket
-      from: nil,
-      till: expiry_time,
-      rtime: nil,
-
-      # certificate time
-      ctime: now
-    }
-    if options[:additional_tickets].present?
-      additional_tickets = options[:additional_tickets]
-      additional_tickets = [additional_tickets] unless additional_tickets.is_a?(::Enumerable)
-      tgs_body_options[:additional_tickets] = additional_tickets
-    end
-
-    tgs_options = {
-      session_key: session_key,
-      subkey: nil,
-      checksum: nil,
-      ticket: tgt_ticket,
-      realm: realm,
-      client_name: client_name,
-      options: ticket_options,
-
-      body: build_tgs_request_body(**tgs_body_options)
-    }
-    if options[:pa_data].present?
-      pa_data = [options[:pa_data]] unless options[:pa_data].is_a?(::Enumerable)
-      tgs_options[:pa_data] = pa_data
-    end
-
-    tgs_res = send_request_tgs(
-        req: build_tgs_request(tgs_options)
-    )
-
-    # Verify error codes
-    if tgs_res.msg_type == Rex::Proto::Kerberos::Model::KRB_ERROR
-      raise ::Rex::Proto::Kerberos::Model::Error::KerberosError.new(res: tgs_res)
-    end
-
-    print_good("#{peer} - Received a valid TGS-Response")
-
-    ccache = extract_kerb_creds(
-      tgs_res,
-      session_key.value,
-      msg_type: Rex::Proto::Kerberos::Crypto::KeyUsage::TGS_REP_ENCPART_SESSION_KEY
-    )
-    if options[:credential_cache_username].present?
-      client = options[:credential_cache_username]
-    else
-      client = self.username
-    end
-    options.fetch(:ticket_storage, @ticket_storage).store_ccache(
-      ccache,
-      host: rhost,
-      client: client,
-      server: sname
-    )
-
-    tgs_ticket = tgs_res.ticket
-    tgs_auth = decrypt_kdc_tgs_rep_enc_part(
-      tgs_res,
-      session_key.value,
-      msg_type: Rex::Proto::Kerberos::Crypto::KeyUsage::TGS_REP_ENCPART_SESSION_KEY
-    )
-
-    [tgs_ticket, tgs_auth]
-  end
-
   # Search the database for a credential object that can be used for authentication.
   #
   # @param [Hash] options
@@ -1053,67 +1067,87 @@ class Msf::Exploit::Remote::Kerberos::ServiceAuthenticator::Base
     )
   end
 
-  # Load a credential object from a file for authentication. Credentials in the file will be filtered by multiple
+  # Load a credential object from a file or database entry for authentication. Credentials in the credential cache will be filtered by multiple
   # attributes including their timestamps to ensure that the returned credential appears usable.
   #
-  # @param [String] file_path The file path to load a credential object from
-  # @return [Rex::Proto::Kerberos::CredentialCache::Krb5CacheCredential] the credential object for authentication
-  def load_credential_from_file(file_path, options = {})
-    unless File.readable?(file_path.to_s)
-      wlog("Failed to load ticket file '#{file_path}' (file not readable)")
-      return nil
-    end
+  # @param [String] path The path to load a credential object from
+  # @return [Hash] :credential [Rex::Proto::Kerberos::CredentialCache::Krb5CacheCredential] the credential object for authentication
+  # @return [Hash] :filter_reasons [Array<String>] the reasons for filtering tickets
+  def load_credential_from_file(path, options = {})
+    # Load a database reference or a path
+    if path&.start_with?('id:')
+      id = path.delete_prefix('id:')
+      storage = Msf::Exploit::Remote::Kerberos::Ticket::Storage::ReadOnly.new(framework: framework)
+      cache = storage.tickets({ id: id  }).first&.ccache
+      unless cache
+        wlog("Invalid cache id #{id} provided")
+        return { credential: nil }
+      end
+    else
+      unless File.readable?(path.to_s)
+        wlog("Failed to load ticket file '#{path}' (file not readable)")
+        return nil
+      end
 
-    begin
-      cache = Rex::Proto::Kerberos::CredentialCache::Krb5Ccache.read(File.binread(file_path))
-    rescue StandardError => e
-      elog("Failed to load ticket file '#{file_path}' (parsing failed)", error: e)
-      return nil
+      begin
+        cache = Rex::Proto::Kerberos::CredentialCache::Krb5Ccache.read(File.binread(path))
+      rescue StandardError => e
+        elog("Failed to load ticket file '#{path}' (parsing failed)", error: e)
+        return nil
+      end
     end
 
     sname = options.fetch(:sname) { build_spn&.to_s }
     sname_hostname = options.fetch(:sname_hostname, nil)
     now = Time.now.utc
 
+    filter = {
+      realm: @realm,
+      sname: sname,
+      sname_hostname: sname_hostname
+    }.merge(options)
+    filter_reasons = []
+
     cache.credentials.to_ary.each.with_index(1) do |credential, index|
       tkt_start = credential.starttime == Time.at(0).utc ? credential.authtime : credential.starttime
       tkt_end = credential.endtime
+      filter_reason_prefix = "Filtered credential #{path} ##{index} reason: "
 
       unless tkt_start < now
-        wlog("Filtered credential #{file_path} ##{index} reason: Ticket start time is before now (start: #{tkt_start})")
+        filter_reasons << "#{filter_reason_prefix}Ticket start time is before now (start: #{tkt_start})"
         next
       end
 
       unless now < tkt_end
-        wlog("Filtered credential #{file_path} ##{index} reason: Ticket is expired (expiration: #{tkt_end})")
+        filter_reasons << "#{filter_reason_prefix}Ticket is expired (expiration: #{tkt_end})"
         next
       end
 
       unless !@realm || @realm.casecmp?(credential.server.realm.to_s)
-        wlog("Filtered credential #{file_path} ##{index} reason: Realm (#{@realm}) does not match (realm: #{credential.server.realm})")
+        filter_reasons << "#{filter_reason_prefix} Realm (#{@realm}) does not match (realm: #{credential.server.realm})"
         next
       end
 
       unless !sname || sname.to_s.casecmp?(credential.server.components.snapshot.join('/'))
-        wlog("Filtered credential #{file_path} ##{index} reason: SPN (#{sname}) does not match (spn: #{credential.server.components.snapshot.join('/')})")
+        filter_reasons << "#{filter_reason_prefix}SPN (#{sname}) does not match (spn: #{credential.server.components.snapshot.join('/')})"
         next
       end
 
       unless !sname_hostname ||
-          sname_hostname.to_s.downcase == credential.server.components[1].downcase ||
-          sname_hostname.to_s.downcase.ends_with?('.' + credential.server.components[1].downcase)
-        wlog("Filtered credential #{file_path} ##{index} reason: SPN (#{sname_hostname}) hostname does not match (spn: #{credential.server.components.snapshot.join('/')})")
+             sname_hostname.to_s.downcase == credential.server.components[1].downcase ||
+             sname_hostname.to_s.downcase.ends_with?('.' + credential.server.components[1].downcase)
+        filter_reasons << "#{filter_reason_prefix}SPN (#{sname_hostname}) hostname does not match (spn: #{credential.server.components.snapshot.join('/')})"
         next
       end
 
       unless !@username || @username.casecmp?(credential.client.components.last.to_s)
-        wlog("Filtered credential #{file_path} ##{index} reason: Username (#{@username}) does not match (username: #{credential.client.components.last})")
+        filter_reasons << "Filtered credential #{path} ##{index} reason: Username (#{@username}) does not match (username: #{credential.client.components.last})"
         next
       end
 
-      return credential
+      return { credential: credential, filter: filter,  filter_reasons: filter_reasons }
     end
 
-    nil
+    { credential: nil, filter: filter, filter_reasons: filter_reasons }
   end
 end
