@@ -74,7 +74,7 @@ module Msf::ModuleManager::Cache
   # @return [false] if a module with the given type and reference name does not exist in the cache.
   # @return (see Msf::Modules::Loader::Base#load_module)
   def load_cached_module(type, reference_name, cache_type: Msf::ModuleManager::Cache::MEMORY)
-    loaded = false
+    cached_metadata = nil
 
     case cache_type
     when Msf::ModuleManager::Cache::FILESYSTEM
@@ -83,7 +83,6 @@ module Msf::ModuleManager::Cache
 
       parent_path = get_parent_path(cached_metadata.path, type)
     when Msf::ModuleManager::Cache::MEMORY
-      cached_metadata = nil
       module_info = self.module_info_by_path.values.find { |inner_info|
         inner_info[:type] == type and inner_info[:reference_name] == reference_name
       }
@@ -94,11 +93,21 @@ module Msf::ModuleManager::Cache
       raise ArgumentError, "#{cache_type} is not a valid cache type."
     end
 
+    try_load_module(parent_path, type, reference_name, cached_metadata: cached_metadata)
+  end
+
+  # @param [String] parent_path Root directory to load modules from
+  # @param [String] reference_name THe module reference name, without the type prefix
+  # @param [String] type Such as auxiliary, exploit, etc
+  # @param [nil,Msf::Modules::Metadata::Obj] cached_metadata
+  # @return [Boolean] True if loaded, false otherwise
+  def try_load_module(parent_path, type, reference_name, cached_metadata: nil)
+    loaded = false
     # XXX borked
     loaders.each do |loader|
-      next unless cached_metadata || loader.loadable_module?(parent_path, type, reference_name)
-
-      loaded = loader.load_module(parent_path, type, reference_name, force: true, cached_metadata: cached_metadata)
+      if loader.loadable_module?(parent_path, type, reference_name, cached_metadata: cached_metadata)
+        loaded = loader.load_module(parent_path, type, reference_name, force: true, cached_metadata: cached_metadata)
+      end
 
       break if loaded
     end
@@ -151,7 +160,7 @@ module Msf::ModuleManager::Cache
 
   # Return a module info from Msf::Modules::Metadata::Obj.
   #
-  # @note Also sets module_set(module_type)[module_reference_name] to Msf::SymbolicModule if it is not already set.
+  # @note Also sets module_set(module_type)[module_reference_name] to nil if it is not already set.
   #
   # @return [Hash{String => Hash{Symbol => Object}}] Maps path (Mdm::Module::Detail#file) to module information.  Module
   #   information is a Hash derived from Mdm::Module::Detail.  It includes :modification_time, :parent_path, :type,
@@ -190,15 +199,13 @@ module Msf::ModuleManager::Cache
       # which would potentially call {Msf::ModuleSet#create}.
       next unless typed_module_set
       unless typed_module_set.has_key?(reference_name)
-        typed_module_set[reference_name] = Msf::SymbolicModule
+        typed_module_set[reference_name] = nil
       end
     end
 
     self.module_info_by_path
   end
 
-  private
-
   def get_parent_path(module_path, type)
     # The load path is assumed to be the next level above the type directory
     type_dir = File.join('', Mdm::Module::Detail::DIRECTORY_BY_TYPE[type], '')
