@@ -52,6 +52,71 @@ module Msf::Post::Common
     "#{rhost}:#{rport}"
   end
 
+  # Create a new process, receiving the program's output
+  # @param executable [String] The path to the executable; either absolute or relative to the session's current directory
+  # @param args [Array<String>] The arguments to the executable
+  # @time_out [Integer] Number of seconds before the call will time out
+  # @param opts [Hash] Optional settings to parameterise the process launch
+  # @option Hidden [Boolean] Is the process launched without creating a visible window
+  # @option Channelized [Boolean] The process is launched with pipes connected to a channel, e.g. for sending input/receiving output
+  # @option Suspended [Boolean] Start the process suspended
+  # @option UseThreadToken [Boolean] Use the thread token (as opposed to the process token) to launch the process
+  # @option Desktop [Boolean] Run on meterpreter's current desktop
+  # @option Session [Integer] Execute process in a given session as the session user
+  # @option Subshell [Boolean] Execute process in a subshell
+  # @option Pty [Boolean] Execute process in a pty (if available)
+  # @option ParentId [Integer] Spoof the parent PID (if possible)
+  # @option InMemory [Boolean,String] Execute from memory (`path` is treated as a local file to upload, and the actual path passed
+  #                                   to meterpreter is this parameter's value, if provided as a String)
+  def create_process(executable, args: [], time_out: 15, opts: {})
+    case session.type
+    when 'meterpreter'
+      session.response_timeout = time_out
+      opts = {
+        'Hidden' => true,
+        'Channelized' => true,
+        # Well-behaving meterpreters will ignore the Subshell flag when using arg arrays.
+        # This is still provided for supporting old meterpreters.
+        'Subshell' => true
+      }.merge(opts)
+
+      if session.platform == 'windows'
+        if session.arch == 'php'
+          opts[:legacy_args] = Msf::Sessions::CommandShellWindows.to_cmd(args)
+          opts[:legacy_path] = Msf::Sessions::CommandShellWindows.to_cmd([executable])
+        elsif session.arch == 'python'
+          opts[:legacy_path] = executable
+          # Yes, Unix. Old Python meterp had a bug where it used posix shell splitting
+          # syntax even on Windows. For backwards-compatibility, we can trick it into
+          # doing the right thing by using Unix escaping.
+          opts[:legacy_args] = Msf::Sessions::CommandShellUnix.to_cmd(args)
+        else
+          opts[:legacy_args] = Msf::Sessions::CommandShellWindows.argv_to_commandline(args)
+          opts[:legacy_path] = Msf::Sessions::CommandShellWindows.escape_cmd(executable)
+        end
+      else
+        opts[:legacy_args] = Msf::Sessions::CommandShellUnix.to_cmd(args)
+        opts[:legacy_path] = Msf::Sessions::CommandShellUnix.to_cmd([executable])
+      end
+
+      if opts['Channelized']
+        o = session.sys.process.capture_output(executable, args, opts, time_out)
+      else
+        session.sys.process.execute(executable, args, opts)
+      end
+    when 'powershell'
+      cmd = session.to_cmd([executable] + args)
+      o = session.shell_command(cmd, time_out)
+      o.chomp! if o
+    when 'shell'
+      cmd = session.to_cmd([executable] + args)
+      o = session.shell_command_token(cmd, time_out)
+      o.chomp! if o
+    end
+    return "" if o.nil?
+    return o
+  end
+
   #
   # Executes +cmd+ on the remote system
   #
