@@ -12,28 +12,35 @@ class MetasploitModule < Msf::Auxiliary
   include Msf::Auxiliary::Report
   include Msf::Auxiliary::Scanner
 
-  def initialize(info={})
-    super(update_info(info,
-      'Name'        => 'Advantech WebAccess Login',
-      'Description' => %q{
-        This module will attempt to authenticate to Advantech WebAccess.
-      },
-      'Author'      => [ 'sinn3r' ],
-      'License'     => MSF_LICENSE,
-      'DefaultOptions' =>
-        {
-          'RPORT'      => 80
+  def initialize(info = {})
+    super(
+      update_info(
+        info,
+        'Name' => 'Advantech WebAccess Login',
+        'Description' => %q{
+          This module will attempt to authenticate to Advantech WebAccess.
+        },
+        'Author' => [ 'sinn3r' ],
+        'License' => MSF_LICENSE,
+        'DefaultOptions' => {
+          'RPORT' => 80
+        },
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
         }
-    ))
+      )
+    )
 
     register_options(
       [
         OptString.new('TARGETURI', [true, 'The base path to Advantech WebAccess', '/']),
         OptBool.new('TRYDEFAULT', [false, 'Try the default credential admin:[empty]', false])
-      ])
+      ]
+    )
   end
 
-
   def scanner(ip)
     @scanner ||= lambda {
       cred_collection = build_credential_collection(
@@ -51,18 +58,18 @@ class MetasploitModule < Msf::Auxiliary
         configure_http_login_scanner(
           host: ip,
           port: datastore['RPORT'],
-          cred_details:       cred_collection,
-          stop_on_success:    datastore['STOP_ON_SUCCESS'],
-          bruteforce_speed:   datastore['BRUTEFORCE_SPEED'],
+          cred_details: cred_collection,
+          stop_on_success: datastore['STOP_ON_SUCCESS'],
+          bruteforce_speed: datastore['BRUTEFORCE_SPEED'],
           connection_timeout: 5,
-          http_username:      datastore['HttpUsername'],
-          http_password:      datastore['HttpPassword'],
-          uri:                target_uri.path
-        ))
+          http_username: datastore['HttpUsername'],
+          http_password: datastore['HttpPassword'],
+          uri: target_uri.path
+        )
+      )
     }.call
   end
 
-
   def report_good_cred(ip, port, result)
     service_data = {
       address: ip,
@@ -90,7 +97,6 @@ class MetasploitModule < Msf::Auxiliary
     create_credential_login(login_data)
   end
 
-
   def report_bad_cred(ip, rport, result)
     invalidate_login(
       address: ip,
