@@ -5,7 +5,6 @@
 
 require 'ruby_smb'
 require 'ruby_smb/gss/provider/ntlm'
-require 'metasploit/framework/hashes/identify'
 
 class MetasploitModule < Msf::Auxiliary
   include ::Msf::Exploit::Remote::SMB::Server
@@ -19,8 +18,7 @@ class MetasploitModule < Msf::Auxiliary
         password NTLMv1 & NTLMv2 hashes used with SMB1, SMB2, or SMB3 client systems.
         Responses sent by this service by default use a random 8 byte challenge string.
         A specific value (such as `1122334455667788`) can be set using the CHALLENGE option,
-        allowing for easy cracking using Cain & Abel (NTLMv1) or John the Ripper
-        (with jumbo patch).
+        allowing for easy cracking using John the Ripper (with jumbo patch).
 
         To exploit this, the target system must try to authenticate to this
         module. One way to force an SMB authentication attempt is by embedding
@@ -42,12 +40,16 @@ class MetasploitModule < Msf::Auxiliary
       'License' => MSF_LICENSE,
       'Actions' => [[ 'Capture', { 'Description' => 'Run SMB capture server' } ]],
       'PassiveActions' => [ 'Capture' ],
-      'DefaultAction' => 'Capture'
+      'DefaultAction' => 'Capture',
+      'Notes' => {
+        'Stability' => [CRASH_SAFE],
+        'SideEffects' => [],
+        'Reliability' => []
+      }
     })
 
     register_options(
       [
-        OptString.new('CAINPWFILE', [ false, 'Name of file to store Cain&Abel hashes in. Only supports NTLMv1 hashes. Can be a path.', nil ]),
         OptString.new('JOHNPWFILE', [ false, 'Name of file to store JohnTheRipper hashes in. Supports NTLMv1 and NTLMv2 hashes, each of which is stored in separate files. Can also be a path.', nil ]),
         OptString.new('CHALLENGE', [ false, 'The 8 byte server challenge. Set values must be a valid 16 character hexadecimal pattern. If unset a valid random challenge is used.' ], regex: /^([a-fA-F0-9]{16})$/),
         OptString.new('SMBDomain', [ true, 'The domain name used during SMB exchange.', 'WORKGROUP'], aliases: ['DOMAIN_NAME']),
@@ -76,9 +78,9 @@ class MetasploitModule < Msf::Auxiliary
     super(opts)
   end
 
-  def on_client_connect(client)
+  def on_client_connect(_client)
     print_good('Received SMB connection on Auth Capture Server!')
   end
 
-  alias :run :exploit
+  alias run exploit
 end
