@@ -28,7 +28,8 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'CVE', '2020-4429' ], # insecure default password
           [ 'URL', 'https://github.com/pedrib/PoC/blob/master/advisories/IBM/ibm_drm/ibm_drm_rce.md' ],
           [ 'URL', 'https://seclists.org/fulldisclosure/2020/Apr/33' ],
-          [ 'URL', 'https://www.ibm.com/blogs/psirt/security-bulletin-vulnerabilities-exist-in-ibm-data-risk-manager-cve-2020-4427-cve-2020-4428-cve-2020-4429-and-cve-2020-4430/']
+          [ 'URL', 'https://www.ibm.com/blogs/psirt/security-bulletin-vulnerabilities-exist-in-ibm-data-risk-manager-cve-2020-4427-cve-2020-4428-cve-2020-4429-and-cve-2020-4430/'],
+          [ 'ATT&CK', Mitre::Attack::Technique::T1021_004_SSH ]
         ],
         'Payload' => {
           'Compat' => {
