@@ -57,7 +57,8 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'BID', '36954' ],
 
           # tomcat docs
-          [ 'URL', 'http://tomcat.apache.org/tomcat-5.5-doc/manager-howto.html' ]
+          [ 'URL', 'http://tomcat.apache.org/tomcat-5.5-doc/manager-howto.html' ],
+          [ 'ATT&CK', Mitre::Attack::Technique::T1021_REMOTE_SERVICES ]
         ],
         'Platform' => %w{java linux win}, # others?
         'Targets' => [
