@@ -417,22 +417,15 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def serve_http_file(path, respond_with = '')
-    # do not use SSL for the attacking web server
-    if datastore['SSL']
-      ssl_restore = true
-      datastore['SSL'] = false
-    end
-
     start_service({
       'Uri' => {
         'Proc' => proc do |cli, _req|
           send_response(cli, respond_with)
         end,
         'Path' => path
-      }
+      },
+      'ssl' => false # do not use SSL
     })
-
-    datastore['SSL'] = true if ssl_restore
   end
 
   def create_json_request(xml_payload)
