@@ -96,6 +96,57 @@ RSpec.describe Msf::Ui::Console::CommandDispatcher::Exploit do
     mod
   end
 
+  let(:ex_mod_with_option_validation) do
+    mod_klass = Class.new(Msf::Exploit) do
+      def initialize(info = {})
+        super(
+          'Name' => 'mock smb module',
+          'Description' => 'mock smb module',
+          'Author' => ['Unknown'],
+          'License' => MSF_LICENSE,
+          'Arch' => ARCH_CMD,
+          'Platform' => ['unix'],
+          'Targets' => [['Automatic', {}]],
+          'DefaultTarget' => 0,
+        )
+
+        register_options(
+          [
+            Msf::OptString.new('USERNAME', [ true, 'Set me to be greeted']),
+            Msf::OptString.new('PASSWORD', [ false, 'Secret value' ])
+          ]
+        )
+      end
+
+      def validate
+        super
+
+        if datastore['PASSWORD'] != 'PleaseThrowTheBall'
+          raise Msf::OptionValidateError.new({'PASSWORD' => 'Nuh uh uh, you didn\'t say the magic word.'})
+        end
+      end
+
+      def check
+        print_status('Check completed!')
+      end
+
+      def run
+        print("Hello #{datastore['USERNAME']}")
+        print_status('Run completed!')
+      end
+
+      alias_method :exploit, :run
+    end
+
+    mod = mod_klass.new
+    datastore = Msf::ModuleDataStore.new(mod)
+    allow(mod).to receive(:framework).and_return(framework)
+    mod.send(:datastore=, datastore)
+    datastore.import_options(mod.options)
+    Msf::Simple::Framework.simplify_module(mod)
+    mod
+  end
+
   subject do
     instance = described_class.new(driver)
     instance
@@ -229,6 +280,40 @@ RSpec.describe Msf::Ui::Console::CommandDispatcher::Exploit do
         expect(@combined_output).to match_array(expected_output)
       end
     end
+
+    context 'when running an exploit module with option validation' do
+      let(:current_mod) { ex_mod_with_option_validation }
+
+      it 'reports options that fail validation' do
+        allow(current_mod).to receive(:check).and_call_original
+        allow(current_mod).to receive(:validate).and_call_original
+        current_mod.datastore['USERNAME'] = 'Jackson'
+        current_mod.datastore['PASSWORD'] = 'ThrowTheBall'
+        subject.cmd_check
+        expected_output = [
+          'Msf::OptionValidateError The following options failed to validate:',
+          'Invalid option PASSWORD: Nuh uh uh, you didn\'t say the magic word.'
+        ]
+
+        expect(@combined_output).to match_array(expected_output)
+        expect(subject.mod).to have_received(:validate).at_least(:once)
+      end
+
+      it 'runs when validation passes' do
+        allow(current_mod).to receive(:check).and_call_original
+        allow(current_mod).to receive(:validate).and_call_original
+        current_mod.datastore['USERNAME'] = 'Jackson'
+        current_mod.datastore['PASSWORD'] = 'PleaseThrowTheBall'
+        subject.cmd_check
+        expected_output = [
+          'Check completed!',
+          'Check failed: The state could not be determined.'
+        ]
+
+        expect(@combined_output).to match_array(expected_output)
+        expect(subject.mod).to have_received(:validate).at_least(:once)
+      end
+    end
   end
 
   describe '#cmd_run' do
@@ -284,7 +369,6 @@ RSpec.describe Msf::Ui::Console::CommandDispatcher::Exploit do
         current_mod.datastore['RHOSTS'] = '192.0.2.1'
         subject.cmd_run
         expected_output = [
-          'Exploit completed, but no session was created.',
           'Msf::OptionValidateError One or more options failed to validate: REQUIRED_PAYLOAD_OPTION.'
         ]
 
@@ -509,6 +593,41 @@ RSpec.describe Msf::Ui::Console::CommandDispatcher::Exploit do
         expect(@combined_output).to match_array(expected_output)
       end
     end
+
+    context 'when running an exploit module with option validation' do
+      let(:current_mod) { ex_mod_with_option_validation }
+
+      it 'reports options that fail validation' do
+        allow(current_mod).to receive(:run).and_call_original
+        allow(current_mod).to receive(:validate).and_call_original
+        current_mod.datastore['USERNAME'] = 'Jackson'
+        current_mod.datastore['PASSWORD'] = 'ThrowTheBall'
+        subject.cmd_run
+        expected_output = [
+          'Msf::OptionValidateError The following options failed to validate:',
+          'Invalid option PASSWORD: Nuh uh uh, you didn\'t say the magic word.'
+        ]
+
+        expect(@combined_output).to match_array(expected_output)
+        expect(subject.mod).to have_received(:validate).at_least(:once)
+      end
+
+      it 'runs when validation passes' do
+        allow(current_mod).to receive(:run).and_call_original
+        allow(current_mod).to receive(:validate).and_call_original
+        current_mod.datastore['USERNAME'] = 'Jackson'
+        current_mod.datastore['PASSWORD'] = 'PleaseThrowTheBall'
+        subject.cmd_run
+        expected_output = [
+          'Hello Jackson',
+          'Run completed!',
+          'Exploit completed, but no session was created.'
+        ]
+
+        expect(@combined_output).to match_array(expected_output)
+        expect(subject.mod).to have_received(:validate).at_least(:once)
+      end
+    end
   end
 
   describe '#cmd_rerun' do
